@@ -4,8 +4,9 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 Components.utils.import("resource://gre/modules/Services.jsm");
+Components.utils.import("resource://gre/modules/PluralForm.jsm");
 
-const nsICookie = Components.interfaces.nsICookie;
+var nsICookie = Components.interfaces.nsICookie;
 
 var gCookiesWindow = {
   _ds               : Components.classes["@mozilla.org/intl/scriptabledateformat;1"]
@@ -26,6 +27,10 @@ var gCookiesWindow = {
     this._populateList(true);
 
     document.getElementById("filter").focus();
+
+    if (!Services.prefs.getBoolPref("privacy.userContext.enabled")) {
+      document.getElementById("userContextRow").hidden = true;
+    }
   },
 
   uninit: function ()
@@ -62,7 +67,9 @@ var gCookiesWindow = {
   {
     return aCookieA.rawHost == aStrippedHost &&
            aCookieA.name == aCookieB.name &&
-           aCookieA.path == aCookieB.path;
+           aCookieA.path == aCookieB.path &&
+           ChromeUtils.isOriginAttributesEqual(aCookieA.originAttributes,
+                                               aCookieB.originAttributes);
   },
 
   observe: function (aCookie, aTopic, aData)
@@ -272,15 +279,19 @@ var gCookiesWindow = {
       var item = this._getItemAtIndex(aIndex);
       if (!item) return;
       this._invalidateCache(aIndex - 1);
-      if (item.container)
+      if (item.container) {
         gCookiesWindow._hosts[item.rawHost] = null;
-      else {
+      } else {
         var parent = this._getItemAtIndex(item.parentIndex);
         for (var i = 0; i < parent.cookies.length; ++i) {
           var cookie = parent.cookies[i];
           if (item.rawHost == cookie.rawHost &&
-              item.name == cookie.name && item.path == cookie.path)
+              item.name == cookie.name &&
+              item.path == cookie.path &&
+              ChromeUtils.isOriginAttributesEqual(item.originAttributes,
+                                                  cookie.originAttributes)) {
             parent.cookies.splice(i, removeCount);
+          }
         }
       }
     },
@@ -470,16 +481,17 @@ var gCookiesWindow = {
   {
     let host = aCookie.host;
     let formattedHost = host.startsWith(".") ? host.substring(1) : host;
-    let c = { name        : aCookie.name,
-              value       : aCookie.value,
-              isDomain    : aCookie.isDomain,
-              host        : aCookie.host,
-              rawHost     : aStrippedHost,
-              path        : aCookie.path,
-              isSecure    : aCookie.isSecure,
-              expires     : aCookie.expires,
-              level       : 1,
-              container   : false };
+    let c = { name            : aCookie.name,
+              value           : aCookie.value,
+              isDomain        : aCookie.isDomain,
+              host            : aCookie.host,
+              rawHost         : aStrippedHost,
+              path            : aCookie.path,
+              isSecure        : aCookie.isSecure,
+              expires         : aCookie.expires,
+              level           : 1,
+              container       : false,
+              originAttributes: aCookie.originAttributes };
     return c;
   },
 
@@ -514,13 +526,18 @@ var gCookiesWindow = {
                                      date.getMinutes(),
                                      date.getSeconds());
     }
-    return this._bundle.getString("AtEndOfSession");
+    return this._bundle.getString("expireAtEndOfSession");
+  },
+
+  _getUserContextString: function(aUserContextId) {
+    // Thunderbird ignores the context for now.
+    return this._bundle.getString("defaultUserContextLabel");
   },
 
   _updateCookieData: function (aItem)
   {
     var seln = this._view.selection;
-    var ids = ["name", "value", "host", "path", "isSecure", "expires"];
+    var ids = ["name", "value", "host", "path", "isSecure", "expires", "userContext"];
     var properties;
 
     if (aItem && !aItem.container && seln.count > 0) {
@@ -529,17 +546,20 @@ var gCookiesWindow = {
                      isDomain: aItem.isDomain ? this._bundle.getString("domainColon")
                                               : this._bundle.getString("hostColon"),
                      isSecure: aItem.isSecure ? this._bundle.getString("forSecureOnly")
-                                              : this._bundle.getString("forAnyConnection") };
-      for (var i = 0; i < ids.length; ++i)
+                                              : this._bundle.getString("forAnyConnection"),
+                     userContext: this._getUserContextString(aItem.originAttributes.userContextId) };
+      for (var i = 0; i < ids.length; ++i) {
         document.getElementById(ids[i]).disabled = false;
+      }
     }
     else {
       var noneSelected = this._bundle.getString("noCookieSelected");
       properties = { name: noneSelected, value: noneSelected, host: noneSelected,
                      path: noneSelected, expires: noneSelected,
-                     isSecure: noneSelected };
-      for (i = 0; i < ids.length; ++i)
+                     isSecure: noneSelected, userContext: noneSelected };
+      for (i = 0; i < ids.length; ++i) {
         document.getElementById(ids[i]).disabled = true;
+      }
     }
     for (var property in properties)
       document.getElementById(property).value = properties[property];
@@ -547,7 +567,7 @@ var gCookiesWindow = {
 
   onCookieSelected: function ()
   {
-    var properties, item;
+    var item;
     var seln = this._tree.view.selection;
     if (!this._view._filtered)
       item = this._view._getItemAtIndex(seln.currentIndex);
@@ -574,11 +594,13 @@ var gCookiesWindow = {
     if (item && seln.count == 1 && item.container && item.open)
       selectedCookieCount += 2;
 
-    var stringKey = selectedCookieCount == 1 ? "removeCookie" : "removeCookies";
-    document.getElementById("removeCookie").label = this._bundle.getString(stringKey);
+    let buttonLabel = this._bundle.getString("removeSelectedCookies");
+    let removeSelectedCookies = document.getElementById("removeSelectedCookies");
+    removeSelectedCookies.label = PluralForm.get(selectedCookieCount, buttonLabel)
+                                            .replace("#1", selectedCookieCount);
 
+    removeSelectedCookies.disabled = !(seln.count > 0);
     document.getElementById("removeAllCookies").disabled = this._view._filtered;
-    document.getElementById("removeCookie").disabled = !(seln.count > 0);
   },
 
   deleteCookie: function ()
@@ -701,7 +723,8 @@ var gCookiesWindow = {
         .getBoolPref("network.cookie.blockFutureCookies");
     for (i = 0; i < deleteItems.length; ++i) {
       var item = deleteItems[i];
-      Services.cookies.remove(item.host, item.name, item.path, blockFutureCookies);
+      Services.cookies.remove(item.host, item.name, item.path,
+                              blockFutureCookies, item.originAttributes);
     }
 
     if (nextSelected < 0)
