@@ -466,12 +466,12 @@ NS_IMETHODIMP nsAbManager::GetUserProfileDirectory(nsIFile **userDir)
   return NS_OK;
 }
 
-NS_IMETHODIMP nsAbManager::MailListNameExists(const char16_t *name, bool *exist)
+NS_IMETHODIMP nsAbManager::MailListNameExists(const char16_t *aName, bool *aExists)
 {
   nsresult rv;
-  NS_ENSURE_ARG_POINTER(exist);
+  NS_ENSURE_ARG_POINTER(aExists);
 
-  *exist = false;
+  *aExists = false;
 
   // now get the top-level book
   nsCOMPtr<nsIAbDirectory> topDirectory;
@@ -482,29 +482,23 @@ NS_IMETHODIMP nsAbManager::MailListNameExists(const char16_t *name, bool *exist)
   rv = topDirectory->GetChildNodes(getter_AddRefs(enumerator));
   NS_ENSURE_SUCCESS(rv, rv);
 
-  nsCOMPtr<nsISupports> item;
-  nsCOMPtr<nsIAbMDBDirectory> directory;
-
   bool hasMore;
-  // XXX Make this not MDB specific.
   while (NS_SUCCEEDED(enumerator->HasMoreElements(&hasMore)) && hasMore)
   {
+    nsCOMPtr<nsISupports> item;
     rv = enumerator->GetNext(getter_AddRefs(item));
     NS_ENSURE_SUCCESS(rv, rv);
 
-    directory = do_QueryInterface(item, &rv);
-    if (NS_SUCCEEDED(rv))
-    {
-        nsCOMPtr<nsIAddrDatabase> database;
-      rv = directory->GetDatabase(getter_AddRefs(database));
-        if (NS_SUCCEEDED(rv))
-        {
-        rv = database->FindMailListbyUnicodeName(name, exist);
-        if (NS_SUCCEEDED(rv) && *exist)
-            return NS_OK;
-        }
-      }
-    }
+    nsCOMPtr<nsIAbDirectory> directory = do_QueryInterface(item, &rv);
+    if (NS_FAILED(rv))
+      continue;
+
+    rv = directory->HasMailListWithName(aName, aExists);
+    if (NS_SUCCEEDED(rv) && *aExists)
+      return NS_OK;
+  }
+
+  *aExists = false;
   return NS_OK;
 }
 
@@ -550,41 +544,43 @@ NS_IMETHODIMP nsAbManager::ExportAddressBook(mozIDOMWindowProxy *aParentWin, nsI
   const char16_t *formatStrings[] = { dirName.get() };
 
   nsString title;
-  rv = bundle->FormatStringFromName(MOZ_UTF16("ExportAddressBookNameTitle"), formatStrings,
+  rv = bundle->FormatStringFromName(u"ExportAddressBookNameTitle", formatStrings,
                                     ArrayLength(formatStrings), getter_Copies(title));
   NS_ENSURE_SUCCESS(rv, rv);
 
   rv = filePicker->Init(aParentWin, title, nsIFilePicker::modeSave);
   NS_ENSURE_SUCCESS(rv, rv);
 
+  filePicker->SetDefaultString(dirName);
+
   nsString filterString;
 
   // CSV: System charset and UTF-8.
-  rv = bundle->GetStringFromName(MOZ_UTF16("CSVFilesSysCharset"), getter_Copies(filterString));
+  rv = bundle->GetStringFromName(u"CSVFilesSysCharset", getter_Copies(filterString));
   NS_ENSURE_SUCCESS(rv, rv);
   rv = filePicker->AppendFilter(filterString, NS_LITERAL_STRING("*.csv"));
   NS_ENSURE_SUCCESS(rv, rv);
-  rv = bundle->GetStringFromName(MOZ_UTF16("CSVFilesUTF8"), getter_Copies(filterString));
+  rv = bundle->GetStringFromName(u"CSVFilesUTF8", getter_Copies(filterString));
   NS_ENSURE_SUCCESS(rv, rv);
   rv = filePicker->AppendFilter(filterString, NS_LITERAL_STRING("*.csv"));
   NS_ENSURE_SUCCESS(rv, rv);
 
   // Tab separated: System charset and UTF-8.
-  rv = bundle->GetStringFromName(MOZ_UTF16("TABFilesSysCharset"), getter_Copies(filterString));
+  rv = bundle->GetStringFromName(u"TABFilesSysCharset", getter_Copies(filterString));
   NS_ENSURE_SUCCESS(rv, rv);
   rv = filePicker->AppendFilter(filterString, NS_LITERAL_STRING("*.tab; *.txt"));
   NS_ENSURE_SUCCESS(rv, rv);
-  rv = bundle->GetStringFromName(MOZ_UTF16("TABFilesUTF8"), getter_Copies(filterString));
+  rv = bundle->GetStringFromName(u"TABFilesUTF8", getter_Copies(filterString));
   NS_ENSURE_SUCCESS(rv, rv);
   rv = filePicker->AppendFilter(filterString, NS_LITERAL_STRING("*.tab; *.txt"));
   NS_ENSURE_SUCCESS(rv, rv);
 
-  rv = bundle->GetStringFromName(MOZ_UTF16("VCFFiles"), getter_Copies(filterString));
+  rv = bundle->GetStringFromName(u"VCFFiles", getter_Copies(filterString));
   NS_ENSURE_SUCCESS(rv, rv);
   rv = filePicker->AppendFilter(filterString, NS_LITERAL_STRING("*.vcf"));
   NS_ENSURE_SUCCESS(rv, rv);
 
-  rv = bundle->GetStringFromName(MOZ_UTF16("LDIFFiles"), getter_Copies(filterString));
+  rv = bundle->GetStringFromName(u"LDIFFiles", getter_Copies(filterString));
   NS_ENSURE_SUCCESS(rv, rv);
   rv = filePicker->AppendFilter(filterString, NS_LITERAL_STRING("*.ldi; *.ldif"));
   NS_ENSURE_SUCCESS(rv, rv);
@@ -721,8 +717,10 @@ nsAbManager::ExportDirectoryToDelimitedText(nsIAbDirectory *aDirectory,
       if (NS_FAILED(bundle->GetStringFromID(EXPORT_ATTRIBUTES_TABLE[i].plainTextStringID, getter_Copies(columnName))))
         columnName.AppendInt(EXPORT_ATTRIBUTES_TABLE[i].plainTextStringID);
 
-      rv = nsMsgI18NConvertFromUnicode(useUTF8 ? "UTF-8" : nsMsgI18NFileSystemCharset(),
-                                       columnName, revisedName);
+      rv = nsMsgI18NConvertFromUnicode(useUTF8 ? NS_LITERAL_CSTRING("UTF-8") :
+                                                 nsMsgI18NFileSystemCharset(),
+                                       columnName,
+                                       revisedName);
       NS_ENSURE_SUCCESS(rv,rv);
 
       rv = outputStream->Write(revisedName.get(),
@@ -812,8 +810,10 @@ nsAbManager::ExportDirectoryToDelimitedText(nsIAbDirectory *aDirectory,
                 newValue.AppendLiteral("\"");
               }
 
-              rv = nsMsgI18NConvertFromUnicode(useUTF8 ? "UTF-8" : nsMsgI18NFileSystemCharset(),
-                                               newValue, valueCStr);
+              rv = nsMsgI18NConvertFromUnicode(useUTF8 ? NS_LITERAL_CSTRING("UTF-8") :
+                                                         nsMsgI18NFileSystemCharset(),
+                                               newValue,
+                                               valueCStr);
               NS_ENSURE_SUCCESS(rv,rv);
 
               if (NS_FAILED(rv)) {
@@ -1163,10 +1163,10 @@ nsresult nsAbManager::AppendDNForCard(const char *aProperty, nsIAbCard *aCard, n
 
   if (!displayName.IsEmpty()) {
     cnStr += NS_ConvertUTF8toUTF16(ldapAttributeName).get();
-    cnStr.AppendLiteral("=");
+    cnStr.Append('=');
     cnStr.Append(displayName);
     if (!email.IsEmpty()) {
-      cnStr.AppendLiteral(",");
+      cnStr.Append(',');
     }
   }
 
@@ -1176,7 +1176,7 @@ nsresult nsAbManager::AppendDNForCard(const char *aProperty, nsIAbCard *aCard, n
 
   if (!email.IsEmpty()) {
     cnStr += NS_ConvertUTF8toUTF16(ldapAttributeName).get();
-    cnStr.AppendLiteral("=");
+    cnStr.Append('=');
     cnStr.Append(email);
   }
 
