@@ -14,6 +14,7 @@
 #include "nsITreeColumns.h"
 #include "nsMsgMessageFlags.h"
 #include <plhash.h>
+#include "mozilla/Attributes.h"
 
 #define MSGHDR_CACHE_LOOK_AHEAD_SIZE  25    // Allocate this more to avoid reallocation on new mail.
 #define MSGHDR_CACHE_MAX_SIZE         8192  // Max msghdr cache entries.
@@ -226,6 +227,7 @@ nsresult nsMsgGroupView::HashHdr(nsIMsgDBHdr *msgHdr, nsString& aHashKey)
       break;
     case nsMsgViewSortType::byReceived:
       rcvDate = true;
+      MOZ_FALLTHROUGH;
     case nsMsgViewSortType::byDate:
     {
       uint32_t ageBucket;
@@ -797,6 +799,7 @@ NS_IMETHODIMP nsMsgGroupView::CellTextForColumn(int32_t aRow,
       {
         case nsMsgViewSortType::byReceived:
           rcvDate = true;
+          MOZ_FALLTHROUGH;
         case nsMsgViewSortType::byDate:
         {
           uint32_t ageBucket = 0;
@@ -805,33 +808,33 @@ NS_IMETHODIMP nsMsgGroupView::CellTextForColumn(int32_t aRow,
           {
           case 1:
             if (m_kTodayString.IsEmpty())
-              m_kTodayString.Adopt(GetString(MOZ_UTF16("today")));
+              m_kTodayString.Adopt(GetString(u"today"));
             aValue.Assign(m_kTodayString);
             break;
           case 2:
             if (m_kYesterdayString.IsEmpty())
-              m_kYesterdayString.Adopt(GetString(MOZ_UTF16("yesterday")));
+              m_kYesterdayString.Adopt(GetString(u"yesterday"));
             aValue.Assign(m_kYesterdayString);
             break;
           case 3:
             if (m_kLastWeekString.IsEmpty())
-              m_kLastWeekString.Adopt(GetString(MOZ_UTF16("lastWeek")));
+              m_kLastWeekString.Adopt(GetString(u"last7Days"));
             aValue.Assign(m_kLastWeekString);
             break;
           case 4:
             if (m_kTwoWeeksAgoString.IsEmpty())
-              m_kTwoWeeksAgoString.Adopt(GetString(MOZ_UTF16("twoWeeksAgo")));
+              m_kTwoWeeksAgoString.Adopt(GetString(u"last14Days"));
             aValue.Assign(m_kTwoWeeksAgoString);
             break;
           case 5:
             if (m_kOldMailString.IsEmpty())
-              m_kOldMailString.Adopt(GetString(MOZ_UTF16("older")));
+              m_kOldMailString.Adopt(GetString(u"older"));
             aValue.Assign(m_kOldMailString);
             break;
           default:
             // Future date, error/spoofed.
             if (m_kFutureDateString.IsEmpty())
-              m_kFutureDateString.Adopt(GetString(MOZ_UTF16("futureDate")));
+              m_kFutureDateString.Adopt(GetString(u"futureDate"));
             aValue.Assign(m_kFutureDateString);
             break;
           }
@@ -846,21 +849,21 @@ NS_IMETHODIMP nsMsgGroupView::CellTextForColumn(int32_t aRow,
         case nsMsgViewSortType::byStatus:
           rv = FetchStatus(m_flags[aRow], aValue);
           if (aValue.IsEmpty()) {
-            tmp_str.Adopt(GetString(MOZ_UTF16("messagesWithNoStatus")));
+            tmp_str.Adopt(GetString(u"messagesWithNoStatus"));
             aValue.Assign(tmp_str);
           }
           break;
         case nsMsgViewSortType::byTags:
           rv = FetchTags(msgHdr, aValue);
           if (aValue.IsEmpty()) {
-            tmp_str.Adopt(GetString(MOZ_UTF16("untaggedMessages")));
+            tmp_str.Adopt(GetString(u"untaggedMessages"));
             aValue.Assign(tmp_str);
           }
           break;
         case nsMsgViewSortType::byPriority:
           FetchPriority(msgHdr, aValue);
           if (aValue.IsEmpty()) {
-            tmp_str.Adopt(GetString(MOZ_UTF16("noPriority")));
+            tmp_str.Adopt(GetString(u"noPriority"));
             aValue.Assign(tmp_str);
           }
           break;
@@ -872,12 +875,12 @@ NS_IMETHODIMP nsMsgGroupView::CellTextForColumn(int32_t aRow,
           break;
         case nsMsgViewSortType::byAttachments:
           tmp_str.Adopt(GetString(flags & nsMsgMessageFlags::Attachment ?
-            MOZ_UTF16("attachments") : MOZ_UTF16("noAttachments")));
+            u"attachments" : u"noAttachments"));
           aValue.Assign(tmp_str);
           break;
         case nsMsgViewSortType::byFlagged:
           tmp_str.Adopt(GetString(flags & nsMsgMessageFlags::Marked ?
-            MOZ_UTF16("groupFlagged") : MOZ_UTF16("notFlagged")));
+            u"groupFlagged" : u"notFlagged"));
           aValue.Assign(tmp_str);
           break;
         // byLocation is a special case; we don't want to have duplicate
@@ -904,7 +907,7 @@ NS_IMETHODIMP nsMsgGroupView::CellTextForColumn(int32_t aRow,
             }
           }
           if (aValue.IsEmpty())
-            aValue.AssignLiteral("*");
+            aValue.Assign('*');
           break;
         }
 
@@ -952,6 +955,9 @@ NS_IMETHODIMP nsMsgGroupView::CellTextForColumn(int32_t aRow,
 
 NS_IMETHODIMP nsMsgGroupView::LoadMessageByViewIndex(nsMsgViewIndex aViewIndex)
 {
+  if (!IsValidIndex(aViewIndex))
+    return NS_MSG_INVALID_DBVIEW_INDEX;
+
   if (m_flags[aViewIndex] & MSG_VIEW_FLAG_DUMMY)
   {
     // if we used to have one item selected, and now we have more than one, we should clear the message pane.
@@ -992,21 +998,6 @@ int32_t nsMsgGroupView::FindLevelInThread(nsIMsgDBHdr *msgHdr,
   return (startOfThread == viewIndex) ? 0 : 1;
 }
 
-
-nsMsgViewIndex nsMsgGroupView::ThreadIndexOfMsg(nsMsgKey msgKey,
-                                            nsMsgViewIndex msgIndex /* = nsMsgViewIndex_None */,
-                                            int32_t *pThreadCount /* = NULL */,
-                                            uint32_t *pFlags /* = NULL */)
-{
-  if (msgIndex != nsMsgViewIndex_None && GroupViewUsesDummyRow())
-  {
-    // this case is all we care about at this point.
-    if (m_flags[msgIndex] & MSG_VIEW_FLAG_ISTHREAD)
-      return msgIndex;
-  }
-  return nsMsgDBView::ThreadIndexOfMsg(msgKey, msgIndex, pThreadCount, pFlags);
-}
-
 bool nsMsgGroupView::GroupViewUsesDummyRow()
 {
   // Return true to always use a header row as root grouped parent row.
@@ -1031,4 +1022,3 @@ NS_IMETHODIMP nsMsgGroupView::AddColumnHandler(const nsAString& column,
 
   return NS_OK;
 }
-
