@@ -41,7 +41,7 @@
 ///////////////////////////////////////////////////////////////////////////
 #ifdef XP_MACOSX
 
-#define AD_WORKING_BUFF_SIZE                  8192
+#define AD_WORKING_BUFF_SIZE FILE_IO_BUFFER_SIZE
 
 extern void         MacGetFileType(nsIFile *fs, bool *useDefault, char **type, char **encoding);
 
@@ -173,7 +173,10 @@ NS_IMETHODIMP nsMsgAttachmentHandler::GetUri(nsACString& aUri)
       turl = m_uri;
   }
   else
-    mURL->GetSpec(turl);
+  {
+    nsresult rv = mURL->GetSpec(turl);
+    NS_ENSURE_SUCCESS(rv, rv);
+  }
   aUri.Assign(turl);
   return NS_OK;
 }
@@ -369,12 +372,14 @@ nsMsgAttachmentHandler::PickEncoding(const char *charset, nsIMsgSend *mime_deliv
   if (pPrefBranch)
     pPrefBranch->GetBoolPref ("mail.file_attach_binary", &forceB64);
 
-  if (!mMainBody && (forceB64 || mime_type_requires_b64_p (m_type.get()) ||
-    m_have_cr + m_have_lf + m_have_crlf != 1))
+  // If the content-type is "image/" or something else known to be binary or
+  // several flavors of newlines are present, use base64 unless we're attaching
+  // a message (so that we don't get confused by newline conversions).
+  if (!mMainBody &&
+      (forceB64 || mime_type_requires_b64_p(m_type.get()) ||
+                   m_have_cr + m_have_lf + m_have_crlf != 1) &&
+      !m_type.LowerCaseEqualsLiteral(MESSAGE_RFC822))
   {
-    // If the content-type is "image/" or something else known to be binary
-    // or several flavors of newlines are present, always use base64
-    // (so that we don't get confused by newline conversions.)
     needsB64 = true;
   }
   else
@@ -739,7 +744,8 @@ nsMsgAttachmentHandler::SnarfAttachment(nsMsgCompFields *compFields)
   }
 
   nsCString sourceURISpec;
-  mURL->GetSpec(sourceURISpec);
+  rv = mURL->GetSpec(sourceURISpec);
+  NS_ENSURE_SUCCESS(rv, rv);
 #ifdef XP_MACOSX
   if (!m_bogus_attachment && StringBeginsWith(sourceURISpec, NS_LITERAL_CSTRING("file://")))
   {
@@ -917,16 +923,7 @@ nsMsgAttachmentHandler::ConvertToAppleEncoding(const nsCString &aFileURI,
       return NS_ERROR_OUT_OF_MEMORY;
     }
 
-    int32_t     bSize = AD_WORKING_BUFF_SIZE;
-
-    char  *working_buff = nullptr;
-    while (!working_buff && (bSize >= 512))
-    {
-      working_buff = (char *)PR_CALLOC(bSize);
-      if (!working_buff)
-        bSize /= 2;
-    }
-
+    char *working_buff = (char *) PR_Malloc(AD_WORKING_BUFF_SIZE);
     if (!working_buff)
     {
       PR_FREEIF(separator);
@@ -935,7 +932,7 @@ nsMsgAttachmentHandler::ConvertToAppleEncoding(const nsCString &aFileURI,
     }
 
     obj->buff = working_buff;
-    obj->s_buff = bSize;
+    obj->s_buff = AD_WORKING_BUFF_SIZE;
 
     //
     //  Setup all the need information on the apple double encoder.
@@ -948,7 +945,7 @@ nsMsgAttachmentHandler::ConvertToAppleEncoding(const nsCString &aFileURI,
     m_size = 0;
     while (status == noErr)
     {
-      status = ap_encode_next(&(obj->ap_encode_obj), obj->buff, bSize, &count);
+      status = ap_encode_next(&(obj->ap_encode_obj), obj->buff, obj->s_buff, &count);
       if (status == noErr || status == errDone)
       {
         //
@@ -975,8 +972,8 @@ nsMsgAttachmentHandler::ConvertToAppleEncoding(const nsCString &aFileURI,
     NS_ENSURE_SUCCESS(rv,rv);
 
     nsCString newURLSpec;
+    rv = fileURI->GetSpec(newURLSpec);
     NS_ENSURE_SUCCESS(rv, rv);
-    fileURI->GetSpec(newURLSpec);
 
     if (newURLSpec.IsEmpty())
     {
@@ -1052,7 +1049,7 @@ nsMsgAttachmentHandler::LoadDataFromFile(nsIFile *file, nsString &sigData, bool
   nsDependentCString cstringReadBuf(readBuf, bytesRead);
   if (charsetConversion)
   {
-    if (NS_FAILED(ConvertToUnicode(m_charset.get(), cstringReadBuf, sigData)))
+    if (NS_FAILED(nsMsgI18NConvertToUnicode(m_charset, cstringReadBuf, sigData)))
       CopyASCIItoUTF16(cstringReadBuf, sigData);
   }
   else
@@ -1164,15 +1161,15 @@ nsMsgAttachmentHandler::UrlExit(nsresult status, const char16_t* aMsg)
         params = unescapedUrl;
     }
     else
-      params.AssignLiteral("?");
+      params.Assign('?');
 
     NS_ConvertUTF8toUTF16 UTF16params(params);
     const char16_t* formatParams[] = { UTF16params.get() };
     if (mode == nsIMsgSend::nsMsgSaveAsDraft || mode == nsIMsgSend::nsMsgSaveAsTemplate)
-      bundle->FormatStringFromName(MOZ_UTF16("failureOnObjectEmbeddingWhileSaving"),
+      bundle->FormatStringFromName(u"failureOnObjectEmbeddingWhileSaving",
                                    formatParams, 1, getter_Copies(msg));
     else
-      bundle->FormatStringFromName(MOZ_UTF16("failureOnObjectEmbeddingWhileSending"),
+      bundle->FormatStringFromName(u"failureOnObjectEmbeddingWhileSending",
                                    formatParams, 1, getter_Copies(msg));
 
     nsCOMPtr<nsIPrompt> aPrompt;
@@ -1225,12 +1222,13 @@ nsMsgAttachmentHandler::UrlExit(nsresult status, const char16_t* aMsg)
           mTmpFile->Remove(false);
 
         nsCOMPtr<nsIOutputStream> outputStream;
-        nsresult rv = NS_NewLocalFileOutputStream(getter_AddRefs(outputStream), mTmpFile,  PR_WRONLY | PR_CREATE_FILE, 00600);
+        nsresult rv = MsgNewBufferedFileOutputStream(getter_AddRefs(outputStream), mTmpFile,
+                                                     PR_WRONLY | PR_CREATE_FILE, 00600);
 
         if (NS_SUCCEEDED(rv))
         {
           nsAutoCString tData;
-          if (NS_FAILED(ConvertFromUnicode(m_charset.get(), conData, tData)))
+          if (NS_FAILED(nsMsgI18NConvertFromUnicode(m_charset, conData, tData)))
             LossyCopyUTF16toASCII(conData, tData);
           if (!tData.IsEmpty())
           {
