@@ -357,7 +357,6 @@ nsresult mime_generate_headers(nsIMsgCompFields *fields,
     finalHeaders->SetRawHeader(HEADER_X_MOZILLA_DRAFT_INFO, draftInfo, nullptr);
   }
 
-
   nsCOMPtr<nsIHttpProtocolHandler> pHTTPHandler = do_GetService(NS_NETWORK_PROTOCOL_CONTRACTID_PREFIX "http", &rv);
   if (NS_SUCCEEDED(rv) && pHTTPHandler)
   {
@@ -438,7 +437,7 @@ nsresult mime_generate_headers(nsIMsgCompFields *fields,
           if (NS_SUCCEEDED(rv))
           {
             nsString undisclosedRecipients;
-            rv = composeStringBundle->GetStringFromName(MOZ_UTF16("undisclosedRecipients"),
+            rv = composeStringBundle->GetStringFromName(u"undisclosedRecipients",
                                                         getter_Copies(undisclosedRecipients));
             if (NS_SUCCEEDED(rv) && !undisclosedRecipients.IsEmpty())
             {
@@ -480,7 +479,7 @@ nsresult mime_generate_headers(nsIMsgCompFields *fields,
       // Output format: [X-Priority: <pValue> (<pName>)]
       priorityValueString.AppendLiteral(" (");
       priorityValueString += priorityName;
-      priorityValueString.AppendLiteral(")");
+      priorityValueString.Append(')');
       finalHeaders->SetRawHeader("X-Priority", priorityValueString, nullptr);
     }
   }
@@ -609,7 +608,7 @@ mime_generate_attachment_headers (const char *type,
       charset.Assign(bodyCharset);
     else
     {
-      charset.Assign(nsMsgI18NFileSystemCharset());
+      charset = nsMsgI18NFileSystemCharset();
       if (!nsMsgI18Ncheck_data_in_charset_range(charset.get(), realName.get()))
         charset.Assign("UTF-8"); // set to UTF-8 if fails again
     }
@@ -723,7 +722,9 @@ mime_generate_attachment_headers (const char *type,
     // Note that we don't need to output the name field if the name encoding is
     // RFC 2231. If the MUA knows the RFC 2231, it should know the RFC 2183 too.
     if (parmFolding != 2) {
-      char *nameValue = LegacyParmFolding(charset, nsDependentCString(real_name),
+      // The underlying JS MIME code will only handle UTF-8 here.
+      char *nameValue = LegacyParmFolding(NS_LITERAL_CSTRING("UTF-8"),
+                                          nsDependentCString(real_name),
                                           parmFolding);
       if (!nameValue || !*nameValue) {
         PR_FREEIF(nameValue);
@@ -977,7 +978,7 @@ RFC2231ParmFolding(const char *parmName, const nsCString& charset,
   if (!NS_IsAscii(parmValue.get()) || is7bitCharset(charset)) {
     needEscape = true;
     nsAutoCString nativeParmValue;
-    ConvertFromUnicode(charset.get(), parmValue, nativeParmValue);
+    nsMsgI18NConvertFromUnicode(charset, parmValue, nativeParmValue);
     MsgEscapeString(nativeParmValue, nsINetUtil::ESCAPE_ALL, dupParm);
   }
   else {
@@ -1402,7 +1403,9 @@ msg_pick_real_name (nsMsgAttachmentHandler *attachment, const char16_t *proposed
   else //Let's extract the name from the URL
   {
     nsCString url;
-    attachment->mURL->GetSpec(url);
+    nsresult rv = attachment->mURL->GetSpec(url);
+    if (NS_FAILED(rv))
+      return;
 
     s = url.get();
     s2 = PL_strchr (s, ':');
