@@ -269,7 +269,7 @@ nsMsgComposeService::GetOrigWindowSelection(MSG_ComposeType type, nsIMsgWindow *
   NS_ENSURE_SUCCESS(rv, rv);
 
   nsCOMPtr<nsIDocShellTreeItem> childAsItem;
-  rv = rootDocShell->FindChildWithName(MOZ_UTF16("messagepane"),
+  rv = rootDocShell->FindChildWithName(NS_LITERAL_STRING("messagepane"),
                                        true, false, nullptr, nullptr, getter_AddRefs(childAsItem));
   NS_ENSURE_SUCCESS(rv, rv);
 
@@ -306,7 +306,7 @@ nsMsgComposeService::GetOrigWindowSelection(MSG_ComposeType type, nsIMsgWindow *
         const uint32_t length = selPlain.Length();
         const char16_t* unicodeStr = selPlain.get();
         int32_t endWordPos = lineBreaker->Next(unicodeStr, length, 0);
-        
+
         // If there's not even one word, then there's not multiple words
         if (endWordPos == NS_LINEBREAKER_NEED_MORE_TEXT)
           return NS_ERROR_ABORT;
@@ -347,7 +347,22 @@ nsMsgComposeService::GetOrigWindowSelection(MSG_ComposeType type, nsIMsgWindow *
   nsAutoString selHTML;
   rv = docEncoder->EncodeToString(selHTML);
   NS_ENSURE_SUCCESS(rv, rv);
-  aSelHTML = NS_ConvertUTF16toUTF8(selHTML);
+
+  // Now remove <span class="moz-txt-citetags">&gt; </span>.
+  nsAutoCString html(NS_ConvertUTF16toUTF8(selHTML).get());
+  int32_t spanInd = html.Find("<span class=\"moz-txt-citetags\">");
+  while (spanInd != kNotFound) {
+    nsAutoCString right0(Substring(html, spanInd));
+    int32_t endInd = right0.Find("</span>");
+    if (endInd == kNotFound)
+      break;  // oops, where is the closing tag gone?
+    nsAutoCString right1(Substring(html, spanInd + endInd + 7));
+    html.SetLength(spanInd);
+    html.Append(right1);
+    spanInd = html.Find("<span class=\"moz-txt-citetags\">");
+  }
+
+  aSelHTML.Assign(html);
 
   return rv;
 }
@@ -358,6 +373,13 @@ nsMsgComposeService::OpenComposeWindow(const char *msgComposeWindowURL, nsIMsgDB
 {
   nsresult rv;
 
+  // Check for any reply type that wants to ignore the quote.
+  bool ignoreQuote = false;
+  if (type >= nsIMsgCompType::ReplyIgnoreQuote) {
+    type -= nsIMsgCompType::ReplyIgnoreQuote;
+    ignoreQuote = true;
+  }
+
   nsCOMPtr<nsIMsgIdentity> identity = aIdentity;
   if (!identity)
     GetDefaultIdentity(getter_AddRefs(identity));
@@ -391,12 +413,13 @@ nsMsgComposeService::OpenComposeWindow(const char *msgComposeWindowURL, nsIMsgDB
       pMsgComposeParams->SetIdentity(identity);
 
       // When doing a reply (except with a template) see if there's a selection that we should quote
-      if (type == nsIMsgCompType::Reply ||
-          type == nsIMsgCompType::ReplyAll ||
-          type == nsIMsgCompType::ReplyToSender ||
-          type == nsIMsgCompType::ReplyToGroup ||
-          type == nsIMsgCompType::ReplyToSenderAndGroup ||
-          type == nsIMsgCompType::ReplyToList)
+      if (!ignoreQuote &&
+          (type == nsIMsgCompType::Reply ||
+           type == nsIMsgCompType::ReplyAll ||
+           type == nsIMsgCompType::ReplyToSender ||
+           type == nsIMsgCompType::ReplyToGroup ||
+           type == nsIMsgCompType::ReplyToSenderAndGroup ||
+           type == nsIMsgCompType::ReplyToList))
       {
         nsAutoCString selHTML;
         if (NS_SUCCEEDED(GetOrigWindowSelection(type, aMsgWindow, selHTML)))
@@ -727,8 +750,8 @@ NS_IMETHODIMP nsMsgTemplateReplyHelper::OnStopRunningUrl(nsIURI *aUrl, nsresult
   rv = mTemplateHdr->GetCharset(getter_Copies(charset));
   NS_ENSURE_SUCCESS(rv, rv);
   compFields->SetCharacterSet(charset.get());
-  rv = nsMsgI18NConvertToUnicode(charset.get(), mTemplateBody, body);
-  NS_WARN_IF_FALSE(NS_SUCCEEDED(rv), "couldn't convert templ body to unicode");
+  rv = nsMsgI18NConvertToUnicode(charset, mTemplateBody, body);
+  NS_WARNING_ASSERTION(NS_SUCCEEDED(rv), "couldn't convert templ body to unicode");
   compFields->SetBody(body);
 
   nsCString msgUri;
@@ -751,8 +774,6 @@ NS_IMETHODIMP nsMsgTemplateReplyHelper::OnStopRunningUrl(nsIURI *aUrl, nsresult
   rv = pMsgCompose->Initialize(pMsgComposeParams, parentWindow, nullptr);
   NS_ENSURE_SUCCESS(rv,rv);
 
-  Release();
-
   return pMsgCompose->SendMsg(nsIMsgSend::nsMsgDeliverNow, mIdentity, nullptr, nullptr, nullptr) ;
 }
 
@@ -889,11 +910,7 @@ NS_IMETHODIMP nsMsgComposeService::ReplyWithTemplate(nsIMsgDBHdr *aMsgHdr, const
   if (!identity) // Found no match -> don't reply.
     return NS_ERROR_ABORT;
 
-  nsMsgTemplateReplyHelper *helper = new nsMsgTemplateReplyHelper;
-  if (!helper)
-    return NS_ERROR_OUT_OF_MEMORY;
-
-  NS_ADDREF(helper);
+  RefPtr<nsMsgTemplateReplyHelper> helper = new nsMsgTemplateReplyHelper;
 
   helper->mHdrToReplyTo = aMsgHdr;
   helper->mMsgWindow = aMsgWindow;
@@ -913,7 +930,7 @@ NS_IMETHODIMP nsMsgComposeService::ReplyWithTemplate(nsIMsgDBHdr *aMsgHdr, const
   if (!query)
     return NS_ERROR_FAILURE;
 
-  nsAutoCString folderUri(Substring(templateUri, query)); 
+  nsAutoCString folderUri(Substring(templateUri, query));
   rv = GetExistingFolder(folderUri, getter_AddRefs(templateFolder));
   NS_ENSURE_SUCCESS(rv, rv);
   rv = templateFolder->GetMsgDatabase(getter_AddRefs(templateDB));
@@ -948,10 +965,11 @@ NS_IMETHODIMP nsMsgComposeService::ReplyWithTemplate(nsIMsgDBHdr *aMsgHdr, const
   nsCOMPtr<nsISupports> listenerSupports;
   helper->QueryInterface(NS_GET_IID(nsISupports), getter_AddRefs(listenerSupports));
 
+  nsCOMPtr<nsIURI> dummyNull;
   rv = msgService->StreamMessage(templateMsgHdrUri.get(), listenerSupports,
                                  aMsgWindow, helper,
                                  false, // convert data
-                                 EmptyCString(), false, nullptr);
+                                 EmptyCString(), false, getter_AddRefs(dummyNull));
   NS_ENSURE_SUCCESS(rv, rv);
 
   nsCOMPtr<nsIMsgFolder> folder;
@@ -993,6 +1011,10 @@ nsMsgComposeService::ForwardMessage(const nsAString &forwardTo,
 
   folder->GetUriForMsg(aMsgHdr, msgUri);
 
+  nsAutoCString uriToOpen(msgUri);
+  uriToOpen += (uriToOpen.FindChar('?') == kNotFound) ? '?' : '&';
+  uriToOpen.Append("fetchCompleteMessage=true");
+
   // get the MsgIdentity for the above key using AccountManager
   nsCOMPtr<nsIMsgAccountManager> accountManager =
     do_GetService (NS_MSGACCOUNTMANAGER_CONTRACTID, &rv);
@@ -1012,10 +1034,10 @@ nsMsgComposeService::ForwardMessage(const nsAString &forwardTo,
   }
 
   if (aForwardType == nsIMsgComposeService::kForwardInline)
-    return RunMessageThroughMimeDraft(msgUri,
+    return RunMessageThroughMimeDraft(uriToOpen,
                                       nsMimeOutput::nsMimeMessageDraftOrTemplate,
                                       identity,
-                                      msgUri.get(), aMsgHdr,
+                                      uriToOpen.get(), aMsgHdr,
                                       true, forwardTo,
                                       false, aMsgWindow);
 
@@ -1039,7 +1061,7 @@ nsMsgComposeService::ForwardMessage(const nsAString &forwardTo,
   pMsgComposeParams->SetFormat(nsIMsgCompFormat::Default);
   pMsgComposeParams->SetIdentity(identity);
   pMsgComposeParams->SetComposeFields(compFields);
-  pMsgComposeParams->SetOriginalMsgURI(msgUri.get());
+  pMsgComposeParams->SetOriginalMsgURI(uriToOpen.get());
   // create the nsIMsgCompose object to send the object
   nsCOMPtr<nsIMsgCompose> pMsgCompose (do_CreateInstance(NS_MSGCOMPOSE_CONTRACTID, &rv));
   NS_ENSURE_SUCCESS(rv, rv);
@@ -1237,7 +1259,7 @@ nsMsgComposeService::LoadDraftOrTemplate(const nsACString& aMsgURI, nsMimeOutput
 }
 
 /**
- * Run the aMsgURI message through libmime. We set various attributes of the 
+ * Run the aMsgURI message through libmime. We set various attributes of the
  * nsIMimeStreamConverter so mimedrft.cpp will know what to do with the message
  * when its done streaming. Usually that will be opening a compose window
  * with the contents of the message, but if forwardTo is non-empty, mimedrft.cpp
@@ -1402,7 +1424,9 @@ nsMsgComposeService::Handle(nsICommandLine* aCmdLine)
         StringBeginsWith(uristr, NS_LITERAL_STRING("subject=")) ||
         StringBeginsWith(uristr, NS_LITERAL_STRING("format=")) ||
         StringBeginsWith(uristr, NS_LITERAL_STRING("body="))  ||
-        StringBeginsWith(uristr, NS_LITERAL_STRING("attachment="))) {
+        StringBeginsWith(uristr, NS_LITERAL_STRING("attachment=")) ||
+        StringBeginsWith(uristr, NS_LITERAL_STRING("message=")) ||
+        StringBeginsWith(uristr, NS_LITERAL_STRING("from="))) {
       composeShouldHandle = true; // the -url argument looks like mailto
       end++;
       // mailto: URIs are frequently passed with spaces in them. They should be
@@ -1445,7 +1469,11 @@ nsMsgComposeService::Handle(nsICommandLine* aCmdLine)
 NS_IMETHODIMP
 nsMsgComposeService::GetHelpInfo(nsACString& aResult)
 {
-  aResult.Assign(NS_LITERAL_CSTRING("  -compose           Compose a mail or news message.\n"));
+  aResult.AssignLiteral(
+    "  -compose [ <options> ] Compose a mail or news message. Options are specified\n"
+    "                     as string \"option='value,...',option=value,...\" and\n"
+    "                     include: from, to, cc, bcc, newsgroups, subject, body,\n"
+    "                     message (file), attachment (file), format (html | text).\n"
+    "                     Example: \"to=john@example.com,subject='Dinner tonight?'\"\n");
   return NS_OK;
 }
-
