@@ -40,6 +40,7 @@
 #include "nsIIDNService.h"
 #include "mozilla/mailnews/MimeHeaderParser.h"
 #include "mozilla/Services.h"
+#include "mozilla/Attributes.h"
 #include "nsINetAddr.h"
 #include "nsIProxyInfo.h"
 
@@ -93,10 +94,15 @@ nsresult nsExplainErrorDetails(nsISmtpUrl * aSmtpUrl, nsresult aCode, ...)
   va_start (args, aCode);
 
   const char16_t* exitString;
+#ifdef __GNUC__
+// Temporary workaroung until bug 783526 is fixed.
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wswitch"
+#endif
   switch (aCode)
   {
     case NS_ERROR_ILLEGAL_LOCALPART:
-      bundle->GetStringFromName(MOZ_UTF16("errorIllegalLocalPart"),
+      bundle->GetStringFromName(u"errorIllegalLocalPart",
                                 getter_Copies(eMsg));
       msg = nsTextFormatter::vsmprintf(eMsg.get(), args);
       break;
@@ -116,10 +122,13 @@ nsresult nsExplainErrorDetails(nsISmtpUrl * aSmtpUrl, nsresult aCode, ...)
       break;
     default:
       NS_WARNING("falling to default error code");
-      bundle->GetStringFromName(MOZ_UTF16("communicationsError"), getter_Copies(eMsg));
+      bundle->GetStringFromName(u"communicationsError", getter_Copies(eMsg));
       msg = nsTextFormatter::smprintf(eMsg.get(), aCode);
       break;
   }
+#ifdef __GNUC__
+#pragma GCC diagnostic pop
+#endif
 
   if (msg)
   {
@@ -385,7 +394,7 @@ void nsSmtpProtocol::AppendHelloArgument(nsACString& aResult)
                   if (family == nsINetAddr::FAMILY_INET6) // IPv6 style address?
                       aResult.AppendLiteral("[IPv6:");
                   else
-                      aResult.AppendLiteral("[");
+                      aResult.Append('[');
 
                   aResult.Append(ipAddressString);
                   aResult.Append(']');
@@ -897,6 +906,7 @@ void nsSmtpProtocol::InitPrefAuthMethods(int32_t authMethodPrefValue)
       MOZ_LOG(SMTPLogModule, mozilla::LogLevel::Error,
           ("SMTP: bad pref authMethod = %d\n", authMethodPrefValue));
       // fall to any
+      MOZ_FALLTHROUGH;
     case nsMsgAuthMethod::anything:
       m_prefAuthMethods =
           SMTP_AUTH_LOGIN_ENABLED | SMTP_AUTH_PLAIN_ENABLED |
@@ -1321,8 +1331,12 @@ nsresult nsSmtpProtocol::AuthLoginStep1()
     if (username.IsEmpty() || password.IsEmpty())
       return NS_ERROR_SMTP_PASSWORD_UNDEFINED;
   }
+
+  nsCString hostname;
+  smtpServer->GetHostname(hostname);
+
   MOZ_LOG(SMTPLogModule, mozilla::LogLevel::Debug, ("SMTP AuthLoginStep1() for %s@%s",
-      username.get(), smtpServer.get()));
+      username.get(), hostname.get()));
 
   GetPassword(password);
   if (password.IsEmpty())
@@ -1711,7 +1725,7 @@ nsresult nsSmtpProtocol::SendDataResponse()
   m_nextState = SMTP_SEND_POST_DATA;
   ClearFlag(SMTP_PAUSE_FOR_READ);   /* send data directly */
 
-  UpdateStatus(MOZ_UTF16("smtpDeliveringMail"));
+  UpdateStatus(u"smtpDeliveringMail");
 
   {
 //      m_runningURL->GetBodySize(&m_totalMessageSize);
@@ -1734,7 +1748,7 @@ void nsSmtpProtocol::SendMessageInFile()
   // for now, we are always done at this point..we aren't making multiple calls
   // to post data...
 
-  UpdateStatus(MOZ_UTF16("smtpDeliveringMail"));
+  UpdateStatus(u"smtpDeliveringMail");
   m_nextState = SMTP_RESPONSE;
   m_nextStateAfterResponse = SMTP_SEND_MESSAGE_RESPONSE;
 }
@@ -1779,7 +1793,7 @@ nsresult nsSmtpProtocol::SendMessageResponse()
     return(NS_ERROR_SENDING_MESSAGE);
   }
 
-  UpdateStatus(MOZ_UTF16("smtpMailSent"));
+  UpdateStatus(u"smtpMailSent");
 
   /* else */
   return SendQuit();
@@ -2167,11 +2181,11 @@ nsSmtpProtocol::PromptForPassword(nsISmtpServer *aSmtpServer, nsISmtpUrl *aSmtpU
   nsString passwordPromptString;
   if(formatStrings[1])
     rv = composeStringBundle->FormatStringFromName(
-      MOZ_UTF16("smtpEnterPasswordPromptWithUsername"),
+      u"smtpEnterPasswordPromptWithUsername",
       formatStrings, 2, getter_Copies(passwordPromptString));
   else
     rv = composeStringBundle->FormatStringFromName(
-      MOZ_UTF16("smtpEnterPasswordPrompt"),
+      u"smtpEnterPasswordPrompt",
       formatStrings, 1, getter_Copies(passwordPromptString));
   NS_ENSURE_SUCCESS(rv, rv);
 
@@ -2181,7 +2195,7 @@ nsSmtpProtocol::PromptForPassword(nsISmtpServer *aSmtpServer, nsISmtpUrl *aSmtpU
 
   nsString passwordTitle;
   rv = composeStringBundle->GetStringFromName(
-    MOZ_UTF16("smtpEnterPasswordPromptTitle"),
+    u"smtpEnterPasswordPromptTitle",
     getter_Copies(passwordTitle));
   NS_ENSURE_SUCCESS(rv,rv);
 
