@@ -605,7 +605,7 @@ nsSmtpServer::GetServerURIInternal(const bool aIncludeUsername)
       MsgEscapeString(username, nsINetUtil::ESCAPE_XALPHAS, escapedUsername);
       // not all servers have a username
       uri.Append(escapedUsername);
-      uri.AppendLiteral("@");
+      uri.Append('@');
     }
   }
 
