@@ -536,7 +536,7 @@ const char* CpToCharset(unsigned int cp)
       {57004, "x-iscii-ta"}, // ISCII Tamil
       {57005, "x-iscii-te"}, // ISCII Telugu
       {57006, "x-iscii-as"}, // ISCII Assamese
-      {57007, "x-iscii-or"}, // ISCII Oriya
+      {57007, "x-iscii-or"}, // ISCII Oriya (Odia)
       {57008, "x-iscii-ka"}, // ISCII Kannada
       {57009, "x-iscii-ma"}, // ISCII Malayalam
       {57010, "x-iscii-gu"}, // ISCII Gujarati
@@ -588,9 +588,9 @@ bool CMapiMessage::CheckBodyInCharsetRange(const char* charset)
   rv = encoder->SetOutputErrorBehavior(nsIUnicodeEncoder::kOnError_Signal, nullptr, 0);
   NS_ENSURE_SUCCESS(rv, false);
 
-  const wchar_t *txt = m_body.get();
+  const char16_t *txt = m_body.get();
   int32_t txtLen = m_body.Length();
-  const wchar_t *currentSrcPtr = txt;
+  const char16_t *currentSrcPtr = txt;
   int srcLength;
   int dstLength;
   char localbuf[512];
@@ -647,7 +647,9 @@ void ExtractMetaCharset(const wchar_t* body, int bodySz, /*out*/nsCString& chars
   const wchar_t* chset_end = std::find_first_of(chset_pos, eohd_pos, term,
                                                 term_end);
   if (chset_end != eohd_pos)
-    LossyCopyUTF16toASCII(Substring(chset_pos, chset_end), charset);
+    LossyCopyUTF16toASCII(Substring(wwc(const_cast<wchar_t *>(chset_pos)),
+                                    wwc(const_cast<wchar_t *>(chset_end))),
+                                    charset);
 }
 
 bool CMapiMessage::FetchBody(void)
@@ -736,11 +738,11 @@ bool CMapiMessage::FetchBody(void)
     }
   }
   if (!bFoundCharset) { // Use system default
-    const char* charset = nsMsgI18NFileSystemCharset();
-    if (charset) {
-      bFoundCharset = CheckBodyInCharsetRange(charset);
+    const nsCString charset(nsMsgI18NFileSystemCharset());
+    if (!charset.IsEmpty()) {
+      bFoundCharset = CheckBodyInCharsetRange(charset.get());
       if (bFoundCharset)
-        m_mimeCharset.Assign(charset);
+        m_mimeCharset = charset;
     }
   }
   if (!bFoundCharset) // Everything else failed, let's use the lossless utf-8...
@@ -754,7 +756,7 @@ bool CMapiMessage::FetchBody(void)
 
 void CMapiMessage::GetBody(nsCString& dest) const
 {
-  nsMsgI18NConvertFromUnicode(m_mimeCharset.get(), m_body, dest);
+  nsMsgI18NConvertFromUnicode(m_mimeCharset, m_body, dest);
 }
 
 void CMapiMessage::FetchFlags(void)
@@ -1282,7 +1284,11 @@ void CMapiMessageHeaders::CHeaderField::GetUnfoldedString(nsString& dest,
   if (m_fbody_utf8)
     CopyUTF8toUTF16(unfolded, dest);
   else
-    nsMsgI18NConvertToUnicode(fallbackCharset, unfolded, dest);
+    nsMsgI18NConvertToUnicode(fallbackCharset ?
+                                nsDependentCString(fallbackCharset) :
+                                EmptyCString(),
+                              unfolded,
+                              dest);
 }
 
 ////////////////////////////////////////
