@@ -6,7 +6,6 @@
 
 #include <mapidefs.h>
 #include <mapi.h>
-#include <tchar.h>
 #include <direct.h>
 #include "nsCOMPtr.h"
 #include "nsIComponentManager.h"
@@ -24,6 +23,7 @@
 #include "nsIPrefBranch.h"
 #include "nsStringGlue.h"
 #include "nsUnicharUtils.h"
+#include "nsNativeCharsetUtils.h"
 #include "nsIMsgAttachment.h"
 #include "nsIMsgCompFields.h"
 #include "nsIMsgComposeParams.h"
@@ -53,8 +53,6 @@ class nsMAPISendListener : public nsIMsgSendListener
 {
 public:
 
-    virtual ~nsMAPISendListener() { }
-
     // nsISupports interface
     NS_DECL_THREADSAFE_ISUPPORTS
 
@@ -96,6 +94,9 @@ protected :
     }
 
     bool            m_done;
+private:
+    virtual ~nsMAPISendListener() { }
+
 };
 
 
@@ -146,7 +147,7 @@ bool nsMapiHook::DisplayLoginDialog(bool aLogin, char16_t **aUsername,
 
     nsString brandName;
     rv = brandBundle->GetStringFromName(
-                       MOZ_UTF16("brandFullName"),
+                       u"brandFullName",
                        getter_Copies(brandName));
     if (NS_FAILED(rv)) return false;
 
@@ -161,7 +162,7 @@ bool nsMapiHook::DisplayLoginDialog(bool aLogin, char16_t **aUsername,
     if (aLogin)
     {
       nsString loginText;
-      rv = bundle->GetStringFromName(MOZ_UTF16("loginTextwithName"),
+      rv = bundle->GetStringFromName(u"loginTextwithName",
                                      getter_Copies(loginText));
       if (NS_FAILED(rv) || loginText.IsEmpty()) return false;
 
@@ -191,7 +192,7 @@ bool nsMapiHook::DisplayLoginDialog(bool aLogin, char16_t **aUsername,
   return btnResult;
 }
 
-bool nsMapiHook::VerifyUserName(const nsString& aUsername, nsCString& aIdKey)
+bool nsMapiHook::VerifyUserName(const nsCString& aUsername, nsCString& aIdKey)
 {
   nsresult rv;
 
@@ -221,7 +222,7 @@ bool nsMapiHook::VerifyUserName(const nsString& aUsername, nsCString& aIdKey)
       if (index != -1)
         email.SetLength(index);
 
-      if (aUsername.Equals(NS_ConvertASCIItoUTF16(email)))
+      if (aUsername.Equals(email))
         return NS_SUCCEEDED(thisIdentity->GetKey(aIdKey));
     }
   }
@@ -255,12 +256,12 @@ nsMapiHook::IsBlindSendAllowed()
   if (NS_FAILED(rv) || !bundle) return false;
 
   nsString warningMsg;
-  rv = bundle->GetStringFromName(MOZ_UTF16("mapiBlindSendWarning"),
+  rv = bundle->GetStringFromName(u"mapiBlindSendWarning",
                                       getter_Copies(warningMsg));
   if (NS_FAILED(rv)) return false;
 
   nsString dontShowAgainMessage;
-  rv = bundle->GetStringFromName(MOZ_UTF16("mapiBlindSendDontShowAgain"),
+  rv = bundle->GetStringFromName(u"mapiBlindSendDontShowAgain",
                                       getter_Copies(dontShowAgainMessage));
   if (NS_FAILED(rv)) return false;
 
@@ -364,89 +365,13 @@ nsresult nsMapiHook::BlindSendMail (unsigned long aSession, nsIMsgCompFields * a
   return rv ;
 }
 
-// this is used to populate comp fields with Unicode data
-nsresult nsMapiHook::PopulateCompFields(lpnsMapiMessage aMessage,
-                                    nsIMsgCompFields * aCompFields)
-{
-  nsresult rv = NS_OK ;
-
-  if (aMessage->lpOriginator)
-    aCompFields->SetFrom (NS_ConvertASCIItoUTF16((char *) aMessage->lpOriginator->lpszAddress));
-
-  nsAutoString To ;
-  nsAutoString Cc ;
-  nsAutoString Bcc ;
-
-  NS_NAMED_LITERAL_STRING(Comma, ",");
-
-  if (aMessage->lpRecips)
-  {
-    for (int i=0 ; i < (int) aMessage->nRecipCount ; i++)
-    {
-      if (aMessage->lpRecips[i].lpszAddress || aMessage->lpRecips[i].lpszName)
-      {
-        const char *addressWithoutType = (aMessage->lpRecips[i].lpszAddress)
-          ? aMessage->lpRecips[i].lpszAddress : aMessage->lpRecips[i].lpszName;
-        if (!PL_strncasecmp(addressWithoutType, "SMTP:", 5))
-          addressWithoutType += 5;
-        switch (aMessage->lpRecips[i].ulRecipClass)
-        {
-        case MAPI_TO :
-          if (!To.IsEmpty())
-            To += Comma;
-          To.Append(NS_ConvertASCIItoUTF16(addressWithoutType));
-          break;
-
-        case MAPI_CC :
-          if (!Cc.IsEmpty())
-            Cc += Comma;
-          Cc.Append(NS_ConvertASCIItoUTF16(addressWithoutType));
-          break;
-
-        case MAPI_BCC :
-          if (!Bcc.IsEmpty())
-            Bcc += Comma;
-          Bcc.Append(NS_ConvertASCIItoUTF16(addressWithoutType));
-          break;
-        }
-      }
-    }
-  }
-
-  MOZ_LOG(MAPI, mozilla::LogLevel::Debug, ("to: %s cc: %s bcc: %s \n", NS_ConvertUTF16toUTF8(To).get(), NS_ConvertUTF16toUTF8(Cc).get(), NS_ConvertUTF16toUTF8(Bcc).get()));
-  // set To, Cc, Bcc
-  aCompFields->SetTo (To) ;
-  aCompFields->SetCc (Cc) ;
-  aCompFields->SetBcc (Bcc) ;
-
-  // set subject
-  if (aMessage->lpszSubject)
-    aCompFields->SetSubject(NS_ConvertASCIItoUTF16(aMessage->lpszSubject));
-
-  // handle attachments as File URL
-  rv = HandleAttachments (aCompFields, aMessage->nFileCount, aMessage->lpFiles, true) ;
-  if (NS_FAILED(rv)) return rv ;
-
-  // set body
-  if (aMessage->lpszNoteText)
-  {
-      nsString Body;
-      CopyASCIItoUTF16(aMessage->lpszNoteText, Body);
-      if (Body.Last() != '\n')
-        Body.AppendLiteral(CRLF);
-
-      if (Body.Find("<html>") == kNotFound)
-        aCompFields->SetForcePlainText(true);
-
-      rv = aCompFields->SetBody(Body) ;
-  }
-  return rv ;
-}
-
 nsresult nsMapiHook::HandleAttachments (nsIMsgCompFields * aCompFields, int32_t aFileCount,
-                                        lpnsMapiFileDesc aFiles, BOOL aIsUnicode)
+                                        lpnsMapiFileDesc aFiles, bool aIsUTF8)
 {
     nsresult rv = NS_OK ;
+    // Do nothing if there are no files to process.
+    if (!aFiles || aFileCount <= 0)
+        return NS_OK;
 
     nsAutoCString Attachments ;
     nsAutoCString TempFiles ;
@@ -458,18 +383,20 @@ nsresult nsMapiHook::HandleAttachments (nsIMsgCompFields * aCompFields, int32_t
 
     for (int i=0 ; i < aFileCount ; i++)
     {
-        bool bTempFile = false ;
         if (aFiles[i].lpszPathName)
         {
             // check if attachment exists
-            if (aIsUnicode)
-                pFile->InitWithPath (nsDependentString(aFiles[i].lpszPathName));
+            if (!aIsUTF8)
+              pFile->InitWithNativePath(nsDependentCString(aFiles[i].lpszPathName));
             else
-                pFile->InitWithNativePath (nsDependentCString((const char*)aFiles[i].lpszPathName));
+              pFile->InitWithPath(NS_ConvertUTF8toUTF16(aFiles[i].lpszPathName));
 
             bool bExist ;
             rv = pFile->Exists(&bExist) ;
-            MOZ_LOG(MAPI, mozilla::LogLevel::Debug, ("nsMapiHook::HandleAttachments: filename: %s path: %s exists = %s \n", (const char*)aFiles[i].lpszFileName, (const char*)aFiles[i].lpszPathName, bExist ? "true" : "false"));
+            MOZ_LOG(MAPI, mozilla::LogLevel::Debug,
+              ("nsMapiHook::HandleAttachments: filename: %s path: %s exists = %s\n",
+               (const char*)aFiles[i].lpszFileName,
+               (const char*)aFiles[i].lpszPathName, bExist ? "true" : "false"));
             if (NS_FAILED(rv) || (!bExist) ) return NS_ERROR_FILE_TARGET_DOES_NOT_EXIST ;
 
             //Temp Directory
@@ -493,11 +420,12 @@ nsresult nsMapiHook::HandleAttachments (nsIMsgCompFields * aCompFields, int32_t
             // a value for lpszFileName, use it. Otherwise stick with leafName
             if (aFiles[i].lpszFileName)
             {
-              nsAutoString wholeFileName;
-                if (aIsUnicode)
-                    wholeFileName.Assign(aFiles[i].lpszFileName);
+                nsAutoString wholeFileName;
+                if (!aIsUTF8)
+                    NS_CopyNativeToUnicode(nsDependentCString(aFiles[i].lpszFileName),
+                                           wholeFileName);
                 else
-                    ConvertToUnicode(nsMsgI18NFileSystemCharset(), (char *) aFiles[i].lpszFileName, wholeFileName);
+                    wholeFileName.Append(NS_ConvertUTF8toUTF16(aFiles[i].lpszFileName));
                 // need to find the last '\' and find the leafname from that.
                 int32_t lastSlash = wholeFileName.RFindChar(char16_t('\\'));
                 if (lastSlash != kNotFound)
@@ -555,16 +483,130 @@ nsresult nsMapiHook::HandleAttachments (nsIMsgCompFields * aCompFields, int32_t
 }
 
 
+nsresult nsMapiHook::HandleAttachmentsW(nsIMsgCompFields* aCompFields, int32_t aFileCount,
+                                        lpnsMapiFileDescW aFiles)
+{
+  nsresult rv = NS_OK ;
+  // Do nothing if there are no files to process.
+  if (!aFiles || aFileCount <= 0)
+      return NS_OK;
+
+  nsAutoCString Attachments ;
+  nsAutoCString TempFiles ;
+
+  nsCOMPtr <nsIFile> pFile = do_CreateInstance(NS_LOCAL_FILE_CONTRACTID, &rv) ;
+  if (NS_FAILED(rv) || (!pFile)) return rv ;
+  nsCOMPtr <nsIFile> pTempDir = do_CreateInstance(NS_LOCAL_FILE_CONTRACTID, &rv) ;
+  if (NS_FAILED(rv) || (!pTempDir)) return rv ;
+
+  for (int i=0 ; i < aFileCount ; i++)
+  {
+    if (aFiles[i].lpszPathName)
+    {
+      // Check if attachment exists.
+      pFile->InitWithPath (nsDependentString(aFiles[i].lpszPathName));
+
+      bool bExist ;
+      rv = pFile->Exists(&bExist) ;
+      MOZ_LOG(MAPI, mozilla::LogLevel::Debug,
+        ("nsMapiHook::HandleAttachmentsW: filename: %s path: %s exists = %s \n",
+         NS_ConvertUTF16toUTF8(aFiles[i].lpszFileName).get(),
+         NS_ConvertUTF16toUTF8(aFiles[i].lpszPathName).get(),
+         bExist ? "true" : "false"));
+      if (NS_FAILED(rv) || (!bExist)) return NS_ERROR_FILE_TARGET_DOES_NOT_EXIST ;
+
+      // Temp Directory.
+      nsCOMPtr <nsIFile> pTempDir;
+      NS_GetSpecialDirectory(NS_OS_TEMP_DIR, getter_AddRefs(pTempDir));
+
+      // Create a new sub directory called moz_mapi underneath the temp directory.
+      pTempDir->AppendRelativePath(NS_LITERAL_STRING("moz_mapi"));
+      pTempDir->Exists(&bExist) ;
+      if (!bExist)
+      {
+        rv = pTempDir->Create(nsIFile::DIRECTORY_TYPE, 777) ;
+        if (NS_FAILED(rv)) return rv ;
+      }
+
+      // Rename or copy the existing temp file with the real file name.
+
+      nsAutoString leafName ;
+      // leafName already contains a unicode leafName from lpszPathName. If we were given
+      // a value for lpszFileName, use it. Otherwise stick with leafName.
+      if (aFiles[i].lpszFileName)
+      {
+        nsAutoString wholeFileName(aFiles[i].lpszFileName);
+        // Need to find the last '\' and find the leafname from that.
+        int32_t lastSlash = wholeFileName.RFindChar(char16_t('\\'));
+        if (lastSlash != kNotFound)
+          leafName.Assign(Substring(wholeFileName, lastSlash + 1));
+        else
+          leafName.Assign(wholeFileName);
+      }
+      else
+        pFile->GetLeafName(leafName);
+
+      nsCOMPtr<nsIMsgAttachment> attachment = do_CreateInstance(NS_MSGATTACHMENT_CONTRACTID, &rv);
+      NS_ENSURE_SUCCESS(rv, rv);
+      attachment->SetName(leafName);
+
+      nsCOMPtr<nsIFile> pTempFile;
+      rv = pTempDir->Clone(getter_AddRefs(pTempFile));
+      if (NS_FAILED(rv) || !pTempFile)
+        return rv;
+
+      pTempFile->Append(leafName);
+      pTempFile->Exists(&bExist);
+      if (bExist)
+      {
+        rv = pTempFile->CreateUnique(nsIFile::NORMAL_FILE_TYPE, 0777);
+        NS_ENSURE_SUCCESS(rv, rv);
+        pTempFile->Remove(false); // remove so we can copy over it.
+        pTempFile->GetLeafName(leafName);
+      }
+      // Copy the file to its new location and file name.
+      pFile->CopyTo(pTempDir, leafName);
+      // Point pFile to the new location of the attachment.
+      pFile->InitWithFile(pTempDir);
+      pFile->Append(leafName);
+
+      // Create MsgCompose attachment object.
+      attachment->SetTemporary(true);  // this one is a temp file so set the flag for MsgCompose
+
+      // Now set the attachment object.
+      nsAutoCString pURL ;
+      NS_GetURLSpecFromFile(pFile, pURL);
+      attachment->SetUrl(pURL);
+
+      // Set the file size.
+      int64_t fileSize;
+      pFile->GetFileSize(&fileSize);
+      attachment->SetSize(fileSize);
+
+      // Add the attachment.
+      rv = aCompFields->AddAttachment (attachment);
+      if (NS_FAILED(rv))
+        MOZ_LOG(MAPI, mozilla::LogLevel::Debug,
+          ("nsMapiHook::HandleAttachmentsW: AddAttachment rv =  %lx\n", rv));
+    }
+  }
+  return rv ;
+}
+
 // this is used to convert non Unicode data and then populate comp fields
 nsresult nsMapiHook::PopulateCompFieldsWithConversion(lpnsMapiMessage aMessage,
                                     nsIMsgCompFields * aCompFields)
 {
   nsresult rv = NS_OK;
+  bool isUTF8 = aMessage->ulReserved == CP_UTF8;
 
   if (aMessage->lpOriginator)
   {
     nsAutoString From;
-    From.Append(NS_ConvertASCIItoUTF16((char *) aMessage->lpOriginator->lpszAddress));
+    if (!isUTF8)
+        From.Append(NS_ConvertASCIItoUTF16(aMessage->lpOriginator->lpszAddress));
+    else
+        From.Append(NS_ConvertUTF8toUTF16(aMessage->lpOriginator->lpszAddress));
     aCompFields->SetFrom (From);
   }
 
@@ -588,19 +630,28 @@ nsresult nsMapiHook::PopulateCompFieldsWithConversion(lpnsMapiMessage aMessage,
         case MAPI_TO :
           if (!To.IsEmpty())
             To += Comma ;
-          To.Append(NS_ConvertASCIItoUTF16(addressWithoutType));
+          if (!isUTF8)
+              To.Append(NS_ConvertASCIItoUTF16(addressWithoutType));
+          else
+              To.Append(NS_ConvertUTF8toUTF16(addressWithoutType));
           break ;
 
         case MAPI_CC :
           if (!Cc.IsEmpty())
             Cc += Comma ;
-          Cc.Append(NS_ConvertASCIItoUTF16(addressWithoutType));
+          if (!isUTF8)
+              Cc.Append(NS_ConvertASCIItoUTF16(addressWithoutType));
+          else
+              Cc.Append(NS_ConvertUTF8toUTF16(addressWithoutType));
           break ;
 
         case MAPI_BCC :
           if (!Bcc.IsEmpty())
               Bcc += Comma ;
-          Bcc.Append(NS_ConvertASCIItoUTF16(addressWithoutType));
+          if (!isUTF8)
+              Bcc.Append(NS_ConvertASCIItoUTF16(addressWithoutType));
+          else
+              Bcc.Append(NS_ConvertUTF8toUTF16(addressWithoutType));
           break ;
         }
       }
@@ -614,33 +665,38 @@ nsresult nsMapiHook::PopulateCompFieldsWithConversion(lpnsMapiMessage aMessage,
 
   MOZ_LOG(MAPI, mozilla::LogLevel::Debug, ("to: %s cc: %s bcc: %s \n", NS_ConvertUTF16toUTF8(To).get(), NS_ConvertUTF16toUTF8(Cc).get(), NS_ConvertUTF16toUTF8(Bcc).get()));
 
-  nsAutoCString platformCharSet;
   // set subject
   if (aMessage->lpszSubject)
   {
     nsAutoString Subject ;
-    if (platformCharSet.IsEmpty())
-      platformCharSet.Assign(nsMsgI18NFileSystemCharset());
-    rv = ConvertToUnicode(platformCharSet.get(), (char *) aMessage->lpszSubject, Subject);
+    if (!isUTF8)
+        rv = NS_CopyNativeToUnicode(nsDependentCString(aMessage->lpszSubject),
+                                    Subject);
+    else
+        Subject.Append(NS_ConvertUTF8toUTF16(aMessage->lpszSubject));
     if (NS_FAILED(rv)) return rv;
     aCompFields->SetSubject(Subject);
   }
 
   // handle attachments as File URL
-  rv = HandleAttachments (aCompFields, aMessage->nFileCount, aMessage->lpFiles, false) ;
+  rv = HandleAttachments(aCompFields, aMessage->nFileCount, aMessage->lpFiles, isUTF8);
   if (NS_FAILED(rv)) return rv ;
 
   // set body
   if (aMessage->lpszNoteText)
   {
     nsAutoString Body ;
-    if (platformCharSet.IsEmpty())
-      platformCharSet.Assign(nsMsgI18NFileSystemCharset());
-    rv = ConvertToUnicode(platformCharSet.get(), (char *) aMessage->lpszNoteText, Body);
+    if (!isUTF8)
+        rv = NS_CopyNativeToUnicode(nsDependentCString(aMessage->lpszNoteText),
+                                    Body);
+    else
+        Body.Append(NS_ConvertUTF8toUTF16(aMessage->lpszNoteText));
     if (NS_FAILED(rv)) return rv ;
-    if (Body.Last() != '\n')
+    if (Body.IsEmpty() || Body.Last() != '\n')
       Body.AppendLiteral(CRLF);
 
+    // This is needed when Simple MAPI is used without a compose window.
+    // See bug 1366196.
     if (Body.Find("<html>") == kNotFound)
       aCompFields->SetForcePlainText(true);
 
@@ -657,12 +713,95 @@ nsresult nsMapiHook::PopulateCompFieldsWithConversion(lpnsMapiMessage aMessage,
   return rv ;
 }
 
+// This is used to populate comp fields with UTF-16 data from MAPISendMailW function.
+nsresult nsMapiHook::PopulateCompFieldsW(lpnsMapiMessageW aMessage,
+                                         nsIMsgCompFields* aCompFields)
+{
+  nsresult rv = NS_OK;
+
+  if (aMessage->lpOriginator)
+    aCompFields->SetFrom(nsDependentString(aMessage->lpOriginator->lpszAddress));
+
+  nsAutoString To;
+  nsAutoString Cc;
+  nsAutoString Bcc;
+
+  NS_NAMED_LITERAL_STRING(Comma, ",");
+
+  if (aMessage->lpRecips)
+  {
+    for (int i=0 ; i < (int)aMessage->nRecipCount ; i++)
+    {
+      if (aMessage->lpRecips[i].lpszAddress || aMessage->lpRecips[i].lpszName)
+      {
+        const wchar_t *addressWithoutType = (aMessage->lpRecips[i].lpszAddress)
+          ? aMessage->lpRecips[i].lpszAddress : aMessage->lpRecips[i].lpszName;
+        if (nsDependentString(addressWithoutType, 5).EqualsASCII("SMTP:") == 0)
+          addressWithoutType += 5;
+        switch (aMessage->lpRecips[i].ulRecipClass)
+        {
+        case MAPI_TO :
+          if (!To.IsEmpty())
+            To += Comma;
+          To.Append(nsDependentString(addressWithoutType));
+          break;
+
+        case MAPI_CC :
+          if (!Cc.IsEmpty())
+            Cc += Comma;
+          Cc.Append(nsDependentString(addressWithoutType));
+          break;
+
+        case MAPI_BCC :
+          if (!Bcc.IsEmpty())
+            Bcc += Comma;
+          Bcc.Append(nsDependentString(addressWithoutType));
+          break;
+        }
+      }
+    }
+  }
+
+  MOZ_LOG(MAPI, mozilla::LogLevel::Debug,
+    ("to: %s cc: %s bcc: %s \n", NS_ConvertUTF16toUTF8(To).get(),
+                                 NS_ConvertUTF16toUTF8(Cc).get(),
+                                 NS_ConvertUTF16toUTF8(Bcc).get()));
+  // set To, Cc, Bcc
+  aCompFields->SetTo(To);
+  aCompFields->SetCc(Cc);
+  aCompFields->SetBcc(Bcc);
+
+  // Set subject.
+  if (aMessage->lpszSubject)
+    aCompFields->SetSubject(nsDependentString(aMessage->lpszSubject));
+
+  // handle attachments as File URL
+  rv = HandleAttachmentsW(aCompFields, aMessage->nFileCount, aMessage->lpFiles);
+  if (NS_FAILED(rv)) return rv;
+
+  // Set body.
+  if (aMessage->lpszNoteText)
+  {
+    nsString Body(aMessage->lpszNoteText);
+    if (Body.IsEmpty() || Body.Last() != '\n')
+      Body.AppendLiteral(CRLF);
+
+    // This is needed when Simple MAPI is used without a compose window.
+    // See bug 1366196.
+    if (Body.Find("<html>") == kNotFound)
+      aCompFields->SetForcePlainText(true);
+
+    rv = aCompFields->SetBody(Body);
+  }
+  return rv;
+}
+
 // this is used to populate the docs as attachments in the Comp fields for Send Documents
 nsresult nsMapiHook::PopulateCompFieldsForSendDocs(nsIMsgCompFields * aCompFields, ULONG aFlags,
-                                                   LPTSTR aDelimChar, LPTSTR aFilePaths)
+                                                   LPSTR aDelimChar, LPSTR aFilePaths)
 {
-  nsAutoString strDelimChars ;
-  nsString strFilePaths;
+  nsAutoCString strDelimChars;
+  nsAutoCString strFilePaths;
   nsresult rv = NS_OK ;
   bool bExist ;
 
@@ -682,7 +821,7 @@ nsresult nsMapiHook::PopulateCompFieldsForSendDocs(nsIMsgCompFields * aCompField
 
   // only 1 file is to be sent, no delim specified
   if (strDelimChars.IsEmpty())
-      strDelimChars.AssignLiteral(";");
+      strDelimChars.Assign(';');
 
   int32_t offset = 0 ;
   int32_t FilePathsLen = strFilePaths.Length() ;
@@ -694,7 +833,7 @@ nsresult nsMapiHook::PopulateCompFieldsForSendDocs(nsIMsgCompFields * aCompField
     nsCOMPtr <nsIFile> pFile = do_CreateInstance (NS_LOCAL_FILE_CONTRACTID, &rv) ;
     if (NS_FAILED(rv) || (!pFile) ) return rv ;
 
-    char16_t * newFilePaths = (char16_t *) strFilePaths.get() ;
+    char *newFilePaths = (char *)strFilePaths.get();
     while (offset != kNotFound)
     {
       //Temp Directory
@@ -711,13 +850,13 @@ nsresult nsMapiHook::PopulateCompFieldsForSendDocs(nsIMsgCompFields * aCompField
         if (NS_FAILED(rv)) return rv ;
       }
 
-      nsString RemainingPaths ;
+      nsAutoCString RemainingPaths;
       RemainingPaths.Assign(newFilePaths) ;
       offset = RemainingPaths.Find (strDelimChars) ;
       if (offset != kNotFound)
       {
         RemainingPaths.SetLength (offset) ;
-        if ((offset + strDelimChars.Length()) < FilePathsLen)
+        if ((offset + (int32_t)strDelimChars.Length()) < FilePathsLen)
           newFilePaths += offset + strDelimChars.Length() ;
         else
           offset = kNotFound;
@@ -729,14 +868,14 @@ nsresult nsMapiHook::PopulateCompFieldsForSendDocs(nsIMsgCompFields * aCompField
         char cwd[MAX_PATH];
         if (_getdcwd(_getdrive(), cwd, MAX_PATH))
         {
-          nsAutoString cwdStr;
-          CopyASCIItoUTF16(cwd, cwdStr);
+          nsAutoCString cwdStr;
+          cwdStr.Assign(cwd);
           cwdStr.Append('\\');
           RemainingPaths.Insert(cwdStr, 0);
         }
       }
 
-      pFile->InitWithPath (RemainingPaths) ;
+      pFile->InitWithNativePath(RemainingPaths) ;
 
       rv = pFile->Exists(&bExist) ;
       if (NS_FAILED(rv) || (!bExist) ) return NS_ERROR_FILE_TARGET_DOES_NOT_EXIST ;
@@ -799,14 +938,20 @@ nsresult nsMapiHook::ShowComposerWindow (unsigned long aSession, nsIMsgCompField
     nsCOMPtr<nsIMsgComposeParams> pMsgComposeParams (do_CreateInstance(NS_MSGCOMPOSEPARAMS_CONTRACTID, &rv));
     if (NS_FAILED(rv) || (!pMsgComposeParams) ) return rv ;
 
+    // If we found HTML, compose in HTML.
     bool forcePlainText;
     aCompFields->GetForcePlainText(&forcePlainText);
     pMsgComposeParams->SetFormat(forcePlainText ? nsIMsgCompFormat::Default : nsIMsgCompFormat::HTML);
+
     // populate the compose params
     pMsgComposeParams->SetType(nsIMsgCompType::New);
-    pMsgComposeParams->SetFormat(nsIMsgCompFormat::Default);
+
+    // Never force to plain text, the default format will take care of that.
+    // Undo the forcing that happened in PopulateCompFields/PopulateCompFieldsWithConversion.
+    // See bug 1095629 and bug 1366196.
+    aCompFields->SetForcePlainText(false);
     pMsgComposeParams->SetComposeFields(aCompFields);
-    pMsgComposeParams->SetSendListener(sendListener) ;
+    pMsgComposeParams->SetSendListener(sendListener);
 
     /** get the nsIMsgComposeService object to open the compose window **/
     nsCOMPtr <nsIMsgComposeService> compService = do_GetService (NS_MSGCOMPOSESERVICE_CONTRACTID) ;
