@@ -4,7 +4,7 @@
 
 #include <mapidefs.h>
 #include <mapi.h>
-#include "msgMapi.h"
+#include <winstring.h>
 #include "msgMapiImp.h"
 #include "msgMapiFactory.h"
 #include "msgMapiMain.h"
@@ -123,8 +123,8 @@ STDMETHODIMP CMapiImp::Initialize()
     return hr;
 }
 
-STDMETHODIMP CMapiImp::Login(unsigned long aUIArg, LOGIN_PW_TYPE aLogin, LOGIN_PW_TYPE aPassWord,
-                unsigned long aFlags, unsigned long *aSessionId)
+STDMETHODIMP CMapiImp::Login(unsigned long aUIArg, LPSTR aLogin, LPSTR aPassWord,
+                             unsigned long aFlags, unsigned long *aSessionId)
 {
     HRESULT hr = E_FAIL;
      bool bNewSession = false;
@@ -137,7 +137,7 @@ STDMETHODIMP CMapiImp::Login(unsigned long aUIArg, LOGIN_PW_TYPE aLogin, LOGIN_P
     // Check For Profile Name
     if (aLogin != nullptr && aLogin[0] != '\0')
     {
-        if (!nsMapiHook::VerifyUserName(nsString(aLogin), id_key))
+        if (!nsMapiHook::VerifyUserName(nsDependentCString(aLogin), id_key))
         {
             *aSessionId = MAPI_E_LOGIN_FAILURE;
             MOZ_LOG(MAPI, mozilla::LogLevel::Debug, ("CMapiImp::Login failed for username %s\n", aLogin));
@@ -169,9 +169,11 @@ STDMETHODIMP CMapiImp::Login(unsigned long aUIArg, LOGIN_PW_TYPE aLogin, LOGIN_P
 
     nsMAPIConfiguration *pConfig = nsMAPIConfiguration::GetMAPIConfiguration();
     if (pConfig != nullptr)
-        nResult = pConfig->RegisterSession(aUIArg, wwc(aLogin), wwc(aPassWord),
-                                           (aFlags & MAPI_FORCE_DOWNLOAD), bNewSession,
-                                           &nSession_Id, id_key.get());
+        nResult = pConfig->RegisterSession(aUIArg,
+            aLogin ? nsDependentCString(aLogin) : EmptyCString(),
+            aPassWord ? nsDependentCString(aPassWord) : EmptyCString(),
+            (aFlags & MAPI_FORCE_DOWNLOAD), bNewSession, 
+            &nSession_Id, id_key.get());
     switch (nResult)
     {
         case -1 :
@@ -196,16 +198,20 @@ STDMETHODIMP CMapiImp::Login(unsigned long aUIArg, LOGIN_PW_TYPE aLogin, LOGIN_P
 }
 
 STDMETHODIMP CMapiImp::SendMail( unsigned long aSession, lpnsMapiMessage aMessage,
-     short aRecipCount, lpnsMapiRecipDesc aRecips , short aFileCount, lpnsMapiFileDesc aFiles , 
      unsigned long aFlags, unsigned long aReserved)
 {
     nsresult rv = NS_OK ;
 
     MOZ_LOG(MAPI, mozilla::LogLevel::Debug, ("CMapiImp::SendMail using flags %d\n", aFlags));
-    // Assign the pointers in the aMessage struct to the array of Recips and Files
-    // received here from MS COM. These are used in BlindSendMail and ShowCompWin fns 
-    aMessage->lpRecips = aRecips ;
-    aMessage->lpFiles = aFiles ;
+
+    // Handle possible nullptr argument.
+    nsMapiMessage Message;
+    memset(&Message, 0, sizeof(nsMapiMessage));
+
+    if (!aMessage)
+    {
+        aMessage = &Message;
+    }
 
     MOZ_LOG(MAPI, mozilla::LogLevel::Debug, ("CMapiImp::SendMail flags=%x subject: %s sender: %s\n", 
       aFlags, (char *) aMessage->lpszSubject, (aMessage->lpOriginator) ? aMessage->lpOriginator->lpszAddress : ""));
@@ -214,11 +220,8 @@ STDMETHODIMP CMapiImp::SendMail( unsigned long aSession, lpnsMapiMessage aMessag
     nsCOMPtr<nsIMsgCompFields> pCompFields = do_CreateInstance(NS_MSGCOMPFIELDS_CONTRACTID, &rv) ;
     if (NS_FAILED(rv) || (!pCompFields) ) return MAPI_E_INSUFFICIENT_MEMORY ;
 
-    if (aFlags & MAPI_UNICODE)
-        rv = nsMapiHook::PopulateCompFields(aMessage, pCompFields) ;
-    else
-        rv = nsMapiHook::PopulateCompFieldsWithConversion(aMessage, pCompFields) ;
-    
+    rv = nsMapiHook::PopulateCompFieldsWithConversion(aMessage, pCompFields);
+
     if (NS_SUCCEEDED (rv))
     {
         // see flag to see if UI needs to be brought up
@@ -235,9 +238,47 @@ STDMETHODIMP CMapiImp::SendMail( unsigned long aSession, lpnsMapiMessage aMessag
     return nsMAPIConfiguration::GetMAPIErrorFromNSError (rv) ;
 }
 
+STDMETHODIMP CMapiImp::SendMailW(unsigned long aSession, lpnsMapiMessageW aMessage,
+                                 unsigned long aFlags, unsigned long aReserved)
+{
+    nsresult rv = NS_OK;
 
-STDMETHODIMP CMapiImp::SendDocuments( unsigned long aSession, LPTSTR aDelimChar,
-                            LPTSTR aFilePaths, LPTSTR aFileNames, ULONG aFlags)
+    MOZ_LOG(MAPI, mozilla::LogLevel::Debug, ("CMapiImp::SendMailW using flags %d\n", aFlags));
+
+    // Handle possible nullptr argument.
+    nsMapiMessageW Message{};
+    if (!aMessage)
+      aMessage = &Message;
+
+    MOZ_LOG(MAPI, mozilla::LogLevel::Debug, ("CMapiImp::SendMailW flags=%x subject: %s sender: %s\n",
+            aFlags,
+            NS_ConvertUTF16toUTF8(aMessage->lpszSubject).get(),
+            NS_ConvertUTF16toUTF8((aMessage->lpOriginator) ? aMessage->lpOriginator->lpszAddress : L"").get()));
+
+    // Create nsIMsgCompFields obj and populate it.
+    nsCOMPtr<nsIMsgCompFields> pCompFields = do_CreateInstance(NS_MSGCOMPFIELDS_CONTRACTID, &rv);
+    if (NS_FAILED(rv) || !pCompFields) return MAPI_E_INSUFFICIENT_MEMORY;
+
+    rv = nsMapiHook::PopulateCompFieldsW(aMessage, pCompFields);
+
+    if (NS_SUCCEEDED (rv))
+    {
+      // Check flag to see if UI needs to be brought up.
+      if (!(aFlags & MAPI_DIALOG))
+      {
+        rv = nsMapiHook::BlindSendMail(aSession, pCompFields);
+      }
+      else
+      {
+        rv = nsMapiHook::ShowComposerWindow(aSession, pCompFields);
+      }
+    }
+
+    return nsMAPIConfiguration::GetMAPIErrorFromNSError(rv);
+}
+
+STDMETHODIMP CMapiImp::SendDocuments(unsigned long aSession, LPSTR aDelimChar,
+                                     LPSTR aFilePaths, LPSTR aFileNames, ULONG aFlags)
 {
     nsresult rv = NS_OK ;
 
@@ -366,9 +407,9 @@ LONG CMapiImp::InitContext(unsigned long session, MsgMapiListContext **listConte
   return SUCCESS_SUCCESS;
 }
 
-STDMETHODIMP CMapiImp::FindNext(unsigned long aSession, unsigned long ulUIParam, LPTSTR lpszMessageType,
-                              LPTSTR lpszSeedMessageID, unsigned long flFlags, unsigned long ulReserved,
-                              unsigned char lpszMessageID[64])
+STDMETHODIMP CMapiImp::FindNext(unsigned long aSession, unsigned long ulUIParam, LPSTR lpszMessageType,
+                                LPSTR lpszSeedMessageID, unsigned long flFlags, unsigned long ulReserved,
+                                unsigned char lpszMessageID[64])
 
 {
   //
@@ -411,8 +452,8 @@ STDMETHODIMP CMapiImp::FindNext(unsigned long aSession, unsigned long ulUIParam,
   return(SUCCESS_SUCCESS);
 }
 
-STDMETHODIMP CMapiImp::ReadMail(unsigned long aSession, unsigned long ulUIParam, LPTSTR lpszMessageID,
-                              unsigned long flFlags, unsigned long ulReserved, lpnsMapiMessage *lppMessage)
+STDMETHODIMP CMapiImp::ReadMail(unsigned long aSession, unsigned long ulUIParam, LPSTR lpszMessageID,
+                                unsigned long flFlags, unsigned long ulReserved, lpnsMapiMessage *lppMessage)
 {
   nsresult irv;
   nsAutoCString keyString((char *) lpszMessageID);
@@ -437,8 +478,8 @@ STDMETHODIMP CMapiImp::ReadMail(unsigned long aSession, unsigned long ulUIParam,
 }
 
 
-STDMETHODIMP CMapiImp::DeleteMail(unsigned long aSession, unsigned long ulUIParam, LPTSTR lpszMessageID,
-                              unsigned long flFlags, unsigned long ulReserved)
+STDMETHODIMP CMapiImp::DeleteMail(unsigned long aSession, unsigned long ulUIParam, LPSTR lpszMessageID,
+                                  unsigned long flFlags, unsigned long ulReserved)
 {
   nsresult irv;
   nsAutoCString keyString((char *) lpszMessageID);
@@ -453,8 +494,8 @@ STDMETHODIMP CMapiImp::DeleteMail(unsigned long aSession, unsigned long ulUIPara
   return (listContext->DeleteMessage(msgKey)) ? SUCCESS_SUCCESS : MAPI_E_INVALID_MESSAGE;
 }
 
-STDMETHODIMP CMapiImp::SaveMail(unsigned long aSession, unsigned long ulUIParam,  lpnsMapiMessage lppMessage,
-                              unsigned long flFlags, unsigned long ulReserved, LPTSTR lpszMessageID)
+STDMETHODIMP CMapiImp::SaveMail(unsigned long aSession, unsigned long ulUIParam, lpnsMapiMessage lppMessage,
+                                unsigned long flFlags, unsigned long ulReserved, LPSTR lpszMessageID)
 {
   MsgMapiListContext *listContext;
   LONG ret = InitContext(aSession, &listContext);
@@ -576,7 +617,7 @@ lpnsMapiMessage MsgMapiListContext::GetMessage (nsMsgKey key, unsigned long flFl
     nsCString author;
     nsCOMPtr <nsIMsgDBHdr> msgHdr;
 
-    nsresult rv = m_db->GetMsgHdrForKey (key, getter_AddRefs(msgHdr));
+    m_db->GetMsgHdrForKey (key, getter_AddRefs(msgHdr));
     if (msgHdr)
     {
       msgHdr->GetSubject (getter_Copies(subject));
