@@ -208,6 +208,14 @@ suite('headerparser', function () {
       ["\"\\\\!\"@a.com", [{name: "", email: "\"\\\\!\"@a.com"}]],
       ["Coward (not@email) <real@email.com>",
         [{name: "Coward (not@email)", email: "real@email.com"}]],
+      ["\"y@example.com\" <xx@example.com>",
+        [{name: "y@example.com", email: "xx@example.com"}]],
+      ["@@@",
+        [{name: "", email: "\"@@\"@"}]],
+      ["@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@",
+        [{name: "", email: "\"@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@\"@"}]],
+      ["Nat Ex <{admin@example.com|stocks@example.com|stockmarket@example.com|trades@example.com|money@example.com|broker@example.com|deals@example.com|offers@example.com|news@example.com|binary@example.com|forex@example.com|marketing@example.com|mail@example.com|inboxdeals@example.com|packages@example.com>",
+        [{name: "Nat Ex", email: "\"{admin@example.com|stocks@example.com|stockmarket@example.com|trades@example.com|money@example.com|broker@example.com|deals@example.com|offers@example.com|news@example.com|binary@example.com|forex@example.com|marketing@example.com|mail@example.com|inboxdeals@example.com|packages\"@example.com"}]],
       ["Group: a@b.com, b@c.com;", [{name: "Group", group:
           [{name: "", email: "a@b.com"}, {name: "", email: "b@c.com"}]}]],
       ["a@invalid.invalid, Group: a@b.com;",
@@ -385,27 +393,27 @@ suite('headerparser', function () {
       ["\"=?UTF-8?Q?Jazzy_Fern=C3=A1ndez_Nunoz?= jazzy.f.nunoz@example.com " +
         "[BCN-FC]\" <Barcelona-Freecycle-noreply@yahoogroups.com>",
         [{name: "Jazzy Fern\u00E1ndez Nunoz jazzy.f.nunoz@example.com [BCN-FC]",
-      email: "Barcelona-Freecycle-noreply@yahoogroups.com"}]],
+          email: "Barcelona-Freecycle-noreply@yahoogroups.com"}]],
       ["\"=?UTF-8?B?TWlyaWFtIEJlcm5hYsOpIFBlcmVsbMOz?= miriam@example.com "+
         "[BCN-FC]\" <Barcelona-Freecycle-noreply@yahoogroups.com>",
         [{name: "Miriam Bernab\u00E9 Perell\u00F3 miriam@example.com [BCN-FC]",
-      email: "Barcelona-Freecycle-noreply@yahoogroups.com"}]],
+          email: "Barcelona-Freecycle-noreply@yahoogroups.com"}]],
       ["\"=?iso-8859-1?Q?First_Mar=EDa_Furi=F3_Gancho?= mail@yahoo.es "+
         "[BCN-FC]\" <Barcelona-Freecycle-noreply@yahoogroups.com>",
         [{name: "First Mar\u00EDa Furi\u00F3 Gancho mail@yahoo.es [BCN-FC]",
-      email: "Barcelona-Freecycle-noreply@yahoogroups.com"}]],
+          email: "Barcelona-Freecycle-noreply@yahoogroups.com"}]],
       ["\"=?iso-8859-1?B?U29maWEgQ2FzdGVsbPMgUm9tZXJv?= sonia@example.com "+
         "[BCN-FC]\" <Barcelona-Freecycle-noreply@yahoogroups.com>",
         [{name: "Sofia Castell\u00F3 Romero sonia@example.com [BCN-FC]",
-      email: "Barcelona-Freecycle-noreply@yahoogroups.com"}]],
+          email: "Barcelona-Freecycle-noreply@yahoogroups.com"}]],
       ["=?iso-8859-1?Q?Klaus_Eisschl=E4ger_=28k=2Eeisschlaeger=40t-onli?=" +
         "=?iso-8859-1?Q?ne=2Ede=29?= <k.eisschlaeger@t-online.de>",
-      [{name: "Klaus Eisschläger (k.eisschlaeger@t-online.de)",
-        email: "k.eisschlaeger@t-online.de"}]],
+        [{name: "Klaus Eisschläger (k.eisschlaeger@t-online.de)",
+          email: "k.eisschlaeger@t-online.de"}]],
       ["\"=?UTF-8?Q?=22Claudia_R=C3=B6hschicht=22?= Claudia_Roehschicht@web.de [freecycle-berlin]\" " +
         "<freecycle-berlin-noreply@yahoogroups.de>",
-      [{name: "\"Claudia Röhschicht\" Claudia_Roehschicht@web.de [freecycle-berlin]",
-        email: "freecycle-berlin-noreply@yahoogroups.de"}]],
+        [{name: "\"Claudia Röhschicht\" Claudia_Roehschicht@web.de [freecycle-berlin]",
+          email: "freecycle-berlin-noreply@yahoogroups.de"}]],
     ];
     header_tests.forEach(function (data) {
       arrayTest(data, function () {
@@ -626,6 +634,26 @@ suite('headerparser', function () {
         "=?UTF-8?Q?f=C3=BCr?="],
       // We don't decode unrecognized charsets (This one is actually UTF-8).
       ["=??B?Sy4gSC4gdm9uIFLDvGRlbg==?=", "=??B?Sy4gSC4gdm9uIFLDvGRlbg==?="],
+
+      // Test for bug 1374149 with ISO-2022-JP where we shouldn't stream
+      // if the first token ends in ESC(B.
+      // GyRCJCIbKEI= is the base64 encoding of ESC$B$"ESC(B.
+      ["=?ISO-2022-JP?B?GyRCJCIbKEI=?==?ISO-2022-JP?B?GyRCJCIbKEI=?=", "ああ"],
+
+      // Tolerate invalid split of character, € = 0xE2 0x82 0xAC in UTF-8.
+      ["Split =?UTF-8?Q?=E2?= =?UTF-8?Q?=82=AC?= after first byte",
+        "Split € after first byte"],
+      ["Split =?UTF-8?Q?=E2=82?= =?UTF-8?Q?=AC?= after second byte",
+        "Split € after second byte"],
+      ["Byte missing =?UTF-8?Q?=E2=82?=",
+        "Byte missing \ufffd"], // Replacement character for invalid input.
+
+      // Test for bug 1301989: Tolerate invalid base64 encoding.
+      ["=?us-ascii?B?YWJjZA==?=", "abcd"],    // correct
+      ["=?us-ascii?B?YWJjZA=?=",  "abc"],     // not a multiple of 4
+      ["=?us-ascii?B?Y=WJjZA==?=", "abcd"],   // invalid =
+      ["=?us-ascii?B?Y=WJj==ZA==?=", "abcd"], // invalid =
+      ["=?us-ascii?B?YWJjZA===?=", "abcd"],   // excess = at the end, see bug 227290.
     ];
     header_tests.forEach(function (data) {
       arrayTest(data, function () {
