@@ -143,9 +143,8 @@ mime_dump_attachments ( nsMsgAttachmentData *attachData )
 
     if ( tmp->m_url )
     {
-      nsAutoCString spec;
-      tmp->m_url->GetSpec(spec);
-      printf("URL               : %s\n", spec.get());
+      ;
+      printf("URL               : %s\n", tmp->m_url->GetSpecOrDefault().get());
     }
 
     printf("Desired Type      : %s\n", tmp->m_desiredType.get());
@@ -189,7 +188,9 @@ nsresult CreateComposeParams(nsCOMPtr<nsIMsgComposeParams> &pMsgComposeParams,
         if (NS_SUCCEEDED(rv) && attachment)
         {
           nsAutoString nameStr;
-          rv = ConvertToUnicode("UTF-8", curAttachment->m_realName.get(), nameStr);
+          rv = nsMsgI18NConvertToUnicode(NS_LITERAL_CSTRING("UTF-8"),
+                                         curAttachment->m_realName,
+                                         nameStr);
           if (NS_FAILED(rv))
             CopyASCIItoUTF16(curAttachment->m_realName, nameStr);
           attachment->SetName(nameStr);
@@ -348,7 +349,9 @@ CreateCompositionFields(const char        *from,
   nsAutoString outString;
 
   if (from) {
-    ConvertRawBytesToUTF16(from, charset, outString);
+    nsMsgI18NConvertRawBytesToUTF16(nsDependentCString(from),
+                                    charset ? nsDependentCString(charset) : EmptyCString(),
+                                    outString);
     cFields->SetFrom(outString);
   }
 
@@ -358,22 +361,30 @@ CreateCompositionFields(const char        *from,
   }
 
   if (reply_to) {
-    ConvertRawBytesToUTF16(reply_to, charset, outString);
+    nsMsgI18NConvertRawBytesToUTF16(nsDependentCString(reply_to),
+                                    charset ? nsDependentCString(charset) : EmptyCString(),
+                                    outString);
     cFields->SetReplyTo(outString);
   }
 
   if (to) {
-    ConvertRawBytesToUTF16(to, charset, outString);
+    nsMsgI18NConvertRawBytesToUTF16(nsDependentCString(to),
+                                    charset ? nsDependentCString(charset) : EmptyCString(),
+                                    outString);
     cFields->SetTo(outString);
   }
 
   if (cc) {
-    ConvertRawBytesToUTF16(cc, charset, outString);
+    nsMsgI18NConvertRawBytesToUTF16(nsDependentCString(cc),
+                                    charset ? nsDependentCString(charset) : EmptyCString(),
+                                    outString);
     cFields->SetCc(outString);
   }
 
   if (bcc) {
-    ConvertRawBytesToUTF16(bcc, charset, outString);
+    nsMsgI18NConvertRawBytesToUTF16(nsDependentCString(bcc),
+                                    charset ? nsDependentCString(charset) : EmptyCString(),
+                                    outString);
     cFields->SetBcc(outString);
   }
 
@@ -653,8 +664,8 @@ mime_insert_all_headers(char            **body,
   bool htmlEdit = (composeFormat == nsIMsgCompFormat::HTML);
   char *newBody = NULL;
   char *html_tag = nullptr;
-  if (*body)
-    html_tag = PL_strcasestr(*body, "<HTML>");
+  if (*body && PL_strncasecmp(*body, "<HTML", 5) == 0)
+    html_tag = PL_strchr(*body, '>') + 1;
   int i;
 
   if (!headers->done_p)
@@ -748,7 +759,7 @@ mime_insert_all_headers(char            **body,
     NS_MsgSACat(&newBody, "</TABLE>");
     NS_MsgSACat(&newBody, MSG_LINEBREAK "<BR><BR>");
     if (html_tag)
-      NS_MsgSACat(&newBody, html_tag+6);
+      NS_MsgSACat(&newBody, html_tag);
     else if (*body)
         NS_MsgSACat(&newBody, *body);
   }
@@ -789,8 +800,8 @@ mime_insert_normal_headers(char             **body,
   char *followup_to = MimeHeaders_get(headers, HEADER_FOLLOWUP_TO, false, true);
   char *references = MimeHeaders_get(headers, HEADER_REFERENCES, false, true);
   const char *html_tag = nullptr;
-  if (*body)
-    html_tag = PL_strcasestr(*body, "<HTML>");
+  if (*body && PL_strncasecmp(*body, "<HTML", 5) == 0)
+    html_tag = PL_strchr(*body, '>') + 1;
   bool htmlEdit = composeFormat == nsIMsgCompFormat::HTML;
 
   if (from.IsEmpty())
@@ -916,7 +927,7 @@ mime_insert_normal_headers(char             **body,
     NS_MsgSACat(&newBody, "</TABLE>");
     NS_MsgSACat(&newBody, MSG_LINEBREAK "<BR><BR>");
     if (html_tag)
-      NS_MsgSACat(&newBody, html_tag+6);
+      NS_MsgSACat(&newBody, html_tag);
     else if (*body)
         NS_MsgSACat(&newBody, *body);
   }
@@ -957,8 +968,8 @@ mime_insert_micro_headers(char            **body,
   char *newsgroups = MimeHeaders_get(headers, HEADER_NEWSGROUPS, false,
                      true);
   const char *html_tag = nullptr;
-  if (*body)
-    html_tag = PL_strcasestr(*body, "<HTML>");
+  if (*body && PL_strncasecmp(*body, "<HTML", 5) == 0)
+    html_tag = PL_strchr(*body, '>') + 1;
   bool htmlEdit = composeFormat == nsIMsgCompFormat::HTML;
 
   if (from.IsEmpty())
@@ -1035,7 +1046,7 @@ mime_insert_micro_headers(char            **body,
     NS_MsgSACat(&newBody, "</TABLE>");
     NS_MsgSACat(&newBody, MSG_LINEBREAK "<BR><BR>");
     if (html_tag)
-      NS_MsgSACat(&newBody, html_tag+6);
+      NS_MsgSACat(&newBody, html_tag);
     else if (*body)
         NS_MsgSACat(&newBody, *body);
   }
@@ -1115,6 +1126,7 @@ mime_parse_stream_complete (nsMIMESession *stream)
   char *foll = 0;
   char *priority = 0;
   char *draftInfo = 0;
+  char *contentLanguage = 0;
   char *identityKey = 0;
 
   bool forward_inline = false;
@@ -1241,6 +1253,11 @@ mime_parse_stream_complete (nsMIMESession *stream)
       mdd->mailcharset,
       getter_AddRefs(fields));
 
+    contentLanguage = MimeHeaders_get(mdd->headers, HEADER_CONTENT_LANGUAGE, false, false);
+    if (contentLanguage) {
+      fields->SetContentLanguage(contentLanguage);
+    }
+
     draftInfo = MimeHeaders_get(mdd->headers, HEADER_X_MOZILLA_DRAFT_INFO, false, false);
 
     // Keep the same message id when editing a draft unless we're
@@ -1258,7 +1275,7 @@ mime_parse_stream_complete (nsMIMESession *stream)
       PR_FREEIF(parm);
 
       parm = MimeHeaders_get_parameter(draftInfo, "receipt", NULL, NULL);
-      if (parm && !strcmp(parm, "0"))
+      if (!parm || !strcmp(parm, "0"))
         fields->SetReturnReceipt(false);
       else
       {
@@ -1310,8 +1327,10 @@ mime_parse_stream_complete (nsMIMESession *stream)
             nsCOMPtr< nsIMsgIdentity > overrulingIdentity;
             rv = accountManager->GetIdentity( nsDependentCString(identityKey), getter_AddRefs( overrulingIdentity ) );
 
-            if ( NS_SUCCEEDED(rv) && overrulingIdentity )
+            if (NS_SUCCEEDED(rv) && overrulingIdentity) {
                 mdd->identity = overrulingIdentity;
+                fields->SetCreatorIdentityKey(identityKey);
+            }
         }
     }
 
@@ -1335,7 +1354,7 @@ mime_parse_stream_complete (nsMIMESession *stream)
       char *body = nullptr;
       uint32_t bodyLen = 0;
 
-      if (!bodyAsAttachment)
+      if (!bodyAsAttachment && mdd->messageBody->m_tmpFile)
       {
         int64_t fileSize;
         nsCOMPtr<nsIFile> tempFileCopy;
@@ -1343,8 +1362,15 @@ mime_parse_stream_complete (nsMIMESession *stream)
         mdd->messageBody->m_tmpFile = do_QueryInterface(tempFileCopy);
         tempFileCopy = nullptr;
         mdd->messageBody->m_tmpFile->GetFileSize(&fileSize);
-        bodyLen = fileSize;
-        body = (char *)PR_MALLOC (bodyLen + 1);
+
+        // The stream interface can only read up to 4GB (32bit uint).
+        // It is highly unlikely to encounter a body lager than that limit,
+        // so we just skip it instead of reading it in chunks.
+        if (fileSize < UINT32_MAX)
+        {
+          bodyLen = fileSize;
+          body = (char *)PR_MALLOC(bodyLen + 1);
+        }
         if (body)
         {
           memset (body, 0, bodyLen+1);
@@ -1370,7 +1396,9 @@ mime_parse_stream_complete (nsMIMESession *stream)
           if (bodyCharset)
           {
             nsAutoString tmpUnicodeBody;
-            rv = ConvertToUnicode(bodyCharset, body, tmpUnicodeBody);
+            rv = nsMsgI18NConvertToUnicode(nsDependentCString(bodyCharset),
+                                           nsDependentCString(body),
+                                           tmpUnicodeBody);
             if (NS_FAILED(rv)) // Tough luck, ASCII/ISO-8859-1 then...
               CopyASCIItoUTF16(nsDependentCString(body), tmpUnicodeBody);
 
@@ -1379,7 +1407,6 @@ mime_parse_stream_complete (nsMIMESession *stream)
             {
               PR_Free(body);
               body = newBody;
-              bodyLen = strlen(newBody);
             }
           }
           PR_FREEIF(mimeCharset);
@@ -1764,6 +1791,8 @@ mime_decompose_file_init_fn ( void *stream_closure, MimeHeaders *headers )
   if (newAttachment->m_description.IsEmpty() && workURLSpec)
     newAttachment->m_description = workURLSpec;
 
+  PR_FREEIF(workURLSpec);     // resource leak otherwise
+
   newAttachment->m_cloudPartInfo.Adopt(MimeHeaders_get(headers,
                                        HEADER_X_MOZILLA_CLOUD_PART,
                                        false, false));
@@ -1829,7 +1858,6 @@ mime_decompose_file_init_fn ( void *stream_closure, MimeHeaders *headers )
                      fileURL.get(), nullptr);
   }
 
-  PR_FREEIF(workURLSpec);
   if (!tmpFile)
     return MIME_OUT_OF_MEMORY;
 
