@@ -171,19 +171,27 @@ MimeMessage_parse_line (const char *aLine, int32_t aLength, MimeObject *obj)
     nl = (length > 0 && (line[length-1] == '\r' || line[length-1] == '\n'));
 
 #ifdef MIME_DRAFTS
-    if ( !mime_typep (kid, (MimeObjectClass*) &mimeMessageClass) &&
-       obj->options &&
-       obj->options->decompose_file_p &&
-       ! obj->options->is_multipart_msg &&
-       obj->options->decompose_file_output_fn )
+    if (!mime_typep (kid, (MimeObjectClass*) &mimeMessageClass) &&
+        obj->options &&
+        obj->options->decompose_file_p &&
+        !obj->options->is_multipart_msg &&
+        obj->options->decompose_file_output_fn &&
+        !obj->options->decrypt_p)
     {
-      if (!obj->options->decrypt_p) {
-        //if we are processing a flowed plain text line, we need to remove any stuffed space
-        if (length > 0 && ' ' == *line && mime_typep(kid, (MimeObjectClass *)&mimeInlineTextPlainFlowedClass))
+      // If we are processing a flowed plain text line, we need to parse the
+      // line in mimeInlineTextPlainFlowedClass.
+      if (mime_typep(kid, (MimeObjectClass *)&mimeInlineTextPlainFlowedClass))
+      {
+        // Remove any stuffed space.
+        if (length > 0 && ' ' == *line)
         {
-          line ++;
-          length --;
+          line++;
+          length--;
         }
+        return kid->clazz->parse_line (line, length, kid);
+      }
+      else
+      {
         status = obj->options->decompose_file_output_fn (line,
                                  length,
                            obj->options->stream_closure);
@@ -277,7 +285,7 @@ MimeMessage_close_headers (MimeObject *obj)
     // If we've got a charset, use nsMsgI18NConvertToUnicode to magically decode
     // the munged subject.
     if (!charset.IsEmpty()) {
-      nsresult rv = nsMsgI18NConvertToUnicode(charset.get(), orig, dest);
+      nsresult rv = nsMsgI18NConvertToUnicode(charset, orig, dest);
       // If we managed to convert the string, replace munged_subject with the
       // UTF8 version of it, otherwise, just forget about it (maybe there was an
       // improperly encoded string in there).
@@ -304,7 +312,7 @@ MimeMessage_close_headers (MimeObject *obj)
       obj->options->decompose_headers_info_fn)
     {
 #ifdef ENABLE_SMIME
-      if (obj->options->decrypt_p && !mime_crypto_object_p (msg->hdrs, false))
+      if (obj->options->decrypt_p && !mime_crypto_object_p(msg->hdrs, false, obj->options))
         obj->options->decrypt_p = false;
 #endif /* ENABLE_SMIME */
       if (!obj->options->caller_need_root_headers || (obj == obj->options->state->root))
@@ -403,7 +411,7 @@ MimeMessage_close_headers (MimeObject *obj)
         obj->options &&
         obj->options->decrypt_p
 #ifdef ENABLE_SMIME
-        && !mime_crypto_object_p (msg->hdrs, false)
+        && !mime_crypto_object_p(msg->hdrs, false, obj->options)
 #endif /* ENABLE_SMIME */
         )
     {
@@ -864,16 +872,16 @@ MimeMessage_partial_message_html(const char *data, void *closure,
 
   partialMsgHtml.AppendLiteral("<span style=\"font-size: 120%;\">");
   if (msgBaseTruncated)
-    item.Adopt(MimeGetStringByName(MOZ_UTF16("MIME_MSG_PARTIAL_TRUNCATED")));
+    item.Adopt(MimeGetStringByName(u"MIME_MSG_PARTIAL_TRUNCATED"));
   else
-    item.Adopt(MimeGetStringByName(MOZ_UTF16("MIME_MSG_PARTIAL_NOT_DOWNLOADED")));
+    item.Adopt(MimeGetStringByName(u"MIME_MSG_PARTIAL_NOT_DOWNLOADED"));
   partialMsgHtml += item;
   partialMsgHtml.AppendLiteral("</span><hr>");
 
   if (msgBaseTruncated)
-    item.Adopt(MimeGetStringByName(MOZ_UTF16("MIME_MSG_PARTIAL_TRUNCATED_EXPLANATION")));
+    item.Adopt(MimeGetStringByName(u"MIME_MSG_PARTIAL_TRUNCATED_EXPLANATION"));
   else
-    item.Adopt(MimeGetStringByName(MOZ_UTF16("MIME_MSG_PARTIAL_NOT_DOWNLOADED_EXPLANATION")));
+    item.Adopt(MimeGetStringByName(u"MIME_MSG_PARTIAL_NOT_DOWNLOADED_EXPLANATION"));
   partialMsgHtml += item;
   partialMsgHtml.AppendLiteral("<br><br>");
 
@@ -899,7 +907,7 @@ MimeMessage_partial_message_html(const char *data, void *closure,
   }
 
   partialMsgHtml.AppendLiteral("\">");
-  item.Adopt(MimeGetStringByName(MOZ_UTF16("MIME_MSG_PARTIAL_CLICK_FOR_REST")));
+  item.Adopt(MimeGetStringByName(u"MIME_MSG_PARTIAL_CLICK_FOR_REST"));
   partialMsgHtml += item;
   partialMsgHtml.AppendLiteral("</a>");
 
