@@ -120,8 +120,8 @@ MimeInlineTextPlainFlowed_parse_begin (MimeObject *obj)
     prefBranch->GetIntPref("mail.quoted_style", &(text->mQuotedStyleSetting));
     prefBranch->GetCharPref("mail.citation_color", &(text->mCitationColor));
     prefBranch->GetBoolPref("mail.strip_sig_on_reply", &(text->mStripSig));
-    nsresult rv = prefBranch->GetBoolPref("mail.fixed_width_messages",
-                                          &(exdata->fixedwidthfont));
+    mozilla::DebugOnly<nsresult> rv =
+      prefBranch->GetBoolPref("mail.fixed_width_messages", &(exdata->fixedwidthfont));
     NS_ASSERTION(NS_SUCCEEDED(rv), "failed to get pref");
          // Check at least the success of one
   }
@@ -318,11 +318,20 @@ MimeInlineTextPlainFlowed_parse_line (const char *aLine, int32_t length, MimeObj
           signature separator, gets special handling
           (RFC 3676) */
     {
-      length--;
+      length = index;
       line[index] = '\0';
     }
   }
 
+  if (obj->options &&
+      obj->options->decompose_file_p &&
+      obj->options->decompose_file_output_fn)
+  {
+    return obj->options->decompose_file_output_fn(line,
+                                                  length,
+                                                  obj->options->stream_closure);
+  }
+
   mozITXTToHTMLConv *conv = GetTextConverter(obj->options);
 
   bool skipConversion = !conv ||
@@ -363,7 +372,9 @@ MimeInlineTextPlainFlowed_parse_line (const char *aLine, int32_t length, MimeObj
           ((MimeInlineTextClass*)&mimeInlineTextClass)->initialize_charset(obj);
         mailCharset = inlinetext->charset;
         if (mailCharset && *mailCharset) {
-          rv = nsMsgI18NConvertToUnicode(mailCharset, PromiseFlatCString(inputStr), lineSource);
+          rv = nsMsgI18NConvertToUnicode(nsDependentCString(mailCharset),
+                                         PromiseFlatCString(inputStr),
+                                         lineSource);
           NS_ENSURE_SUCCESS(rv, -1);
         }
         else // this probably never happens...
@@ -462,7 +473,9 @@ MimeInlineTextPlainFlowed_parse_line (const char *aLine, int32_t length, MimeObj
       CopyUTF16toUTF8(lineResult2, outString);
     else
     { // convert back to mailCharset before writing.
-      rv = nsMsgI18NConvertFromUnicode(mailCharset, lineResult2, outString);
+      rv = nsMsgI18NConvertFromUnicode(nsDependentCString(mailCharset),
+                                       lineResult2,
+                                       outString);
       NS_ENSURE_SUCCESS(rv, -1);
     }
     status = MimeObject_write(obj, outString.get(), outString.Length(), true);
@@ -571,7 +584,7 @@ static void Convert_whitespace(const char16_t a_current_char,
 
   while(number_of_space--) {
     // a_out_string += ' '; gives error
-    a_out_string.AppendLiteral(" ");
+    a_out_string.Append(' ');
   }
 
   return;
