@@ -20,7 +20,7 @@ const kPreexistingDomains = 13;
 function test() {
   // Preload data.
   // Note that before this test starts, what is already set are permissions for
-  // addons.mozilla.org to install addons as well as
+  // addons.thunderbird.net to install addons as well as
   // permissions for a number of sites used in mochitest to load XUL/XBL.
   // For the latter, those 13 domains are used/listed: 127.0.0.1, bank1.com,
   // bank2.com, example.com, example.org, mochi.test, mozilla.com, test,
@@ -38,20 +38,20 @@ function test() {
 
   // Add cookie: not secure, non-HTTPOnly, session
   Services.cookies.add("bar.geckoisgecko.org", "", "name0", "value0",
-                       false, false, true, now_epoch + 600);
+                       false, false, true, now_epoch + 600, {});
   // Add cookie: not secure, HTTPOnly, session
   Services.cookies.add("foo.geckoisgecko.org", "", "name1", "value1",
-                       false, true, true, now_epoch + 600);
+                       false, true, true, now_epoch + 600, {});
   // Add cookie: secure, HTTPOnly, session
   Services.cookies.add("secure.geckoisgecko.org", "", "name2", "value2",
-                       true, true, true, now_epoch + 600);
+                       true, true, true, now_epoch + 600, {});
   // Add cookie: secure, non-HTTPOnly, expiry in an hour
   Services.cookies.add("drumbeat.org", "", "name3", "value3",
-                       true, false, false, now_epoch + 3600);
+                       true, false, false, now_epoch + 3600, {});
 
   // Add a cookie for a pure IPv6 address.
   Services.cookies.add("::1", "", "name4", "value4",
-                       false, false, true, now_epoch + 600);
+                       false, false, true, now_epoch + 600, {});
 
   // Add a few form history entries
   gLocSvc.fhist.addEntry("akey", "value0");
@@ -696,8 +696,8 @@ function test_idn(aWin) {
   let idnDomain = gLocSvc.idn.convertToDisplayIDN(testDomain, {});
   isnot(testDomain, idnDomain, "Using a valid IDN domain");
   // Add IDN cookie.
-  Services.cookies.add(testDomain, "", "name0", "value0",
-                       false, false, true, parseInt(Date.now() / 1000) + 600);
+  Services.cookies.add(testDomain, "", "name0", "value0", false, false, true,
+                       parseInt(Date.now() / 1000) + 600, {});
 
   aWin.document.getElementById("domainSearch").value = "xn--";
   aWin.document.getElementById("domainSearch").doCommand();
