@@ -4,6 +4,8 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
+Components.utils.import("resource://gre/modules/Services.jsm");
+Components.utils.import("resource:///modules/gloda/utils.js");
 
 /* This is where functions related to displaying the headers for a selected message in the
    message pane live. */
@@ -179,7 +181,7 @@ function initializeHeaderViewTables()
   // for each one. These header entries are then stored in the appropriate header table
   for (let index = 0; index < gCollapsedHeaderList.length; index++)
   {
-    gCollapsedHeaderView[gCollapsedHeaderList[index].name] = 
+    gCollapsedHeaderView[gCollapsedHeaderList[index].name] =
       new createHeaderEntry('collapsed', gCollapsedHeaderList[index]);
   }
 
@@ -248,7 +250,7 @@ function OnLoadMsgHeaderPane()
   var toggleHeaderView = GetHeaderPane();
   var initialCollapsedSetting = toggleHeaderView.getAttribute("state");
   if (initialCollapsedSetting == "true")
-    gCollapsedHeaderViewMode = true;   
+    gCollapsedHeaderViewMode = true;
 
   // dispatch an event letting any listeners know that we have loaded the message pane
   toggleHeaderView.dispatchEvent(new Event('messagepane-loaded',
@@ -472,7 +474,7 @@ var messageHeaderSink = {
               var createCard = (gCollectIncoming && !dontCollectAddress) || (gCollectNewsgroup && dontCollectAddress);
               if (createCard || gCollectOutgoing)
               {
-                // collect, add card if doesn't exist and gCollectOutgoing is set, 
+                // collect, add card if doesn't exist and gCollectOutgoing is set,
                 // otherwise only update existing cards, unknown preferred send format
                 gCollectAddressTimer = setTimeout(collectAddresses,
                                                   2000,
@@ -610,6 +612,24 @@ var messageHeaderSink = {
       }
       if (!currentAttachments.length && this.mSaveHdr)
         this.mSaveHdr.markHasAttachments(false);
+
+      let browser = getBrowser();
+      if (currentAttachments.length &&
+          Services.prefs.getBoolPref("mail.inline_attachments") &&
+          this.mSaveHdr && gFolderDisplay.selectedMessageIsFeed &&
+          browser && browser.contentDocument && browser.contentDocument.body) {
+        for (let img of browser.contentDocument.body.getElementsByClassName("moz-attached-image")) {
+          for (let attachment of currentAttachments) {
+            let partID = img.src.split("&part=")[1];
+            partID = partID ? partID.split("&")[0] : null;
+            if (attachment.partID && partID == attachment.partID) {
+              img.src = attachment.url;
+              break;
+            }
+          }
+        }
+      }
+
       OnMsgParsed(url);
     },
 
@@ -618,9 +638,9 @@ var messageHeaderSink = {
       OnMsgLoaded(url);
     },
 
-    onMsgHasRemoteContent: function(aMsgHdr, aContentURI)
+    onMsgHasRemoteContent: function(aMsgHdr, aContentURI, aCanOverride)
     {
-      gMessageNotificationBar.setRemoteContentMsg(aMsgHdr, aContentURI);
+      gMessageNotificationBar.setRemoteContentMsg(aMsgHdr, aContentURI, aCanOverride);
     },
 
     mSecurityInfo  : null,
@@ -677,7 +697,7 @@ function SetTagHeader()
                    .getService(Components.interfaces.nsIMsgTagService);
   var tagArray = tagService.getAllTags({});
   var tagKeys = {};
-  for each (var tagInfo in tagArray)
+  for (var tagInfo of tagArray)
     if (tagInfo.tag)
       tagKeys[tagInfo.key] = true;
 
@@ -729,7 +749,7 @@ function collectAddresses(aAddresses, aCreateCard)
 }
 
 // Public method called by the tag front end code when the tags for the selected
-// message has changed. 
+// message has changed.
 function OnTagsChange()
 {
   // rebuild the tag headers
@@ -823,7 +843,7 @@ function ToggleHeaderView()
     hideHeaderView(gCollapsedHeaderView);
     // update the current view
     UpdateMessageHeaders();
-    
+
     // now uncollapse / collapse the right views
     expandedNode.collapsed = false;
     collapsedNode.collapsed = true;
@@ -835,11 +855,11 @@ function ToggleHeaderView()
     hideHeaderView(gExpandedHeaderView);
     // update the current view
     UpdateMessageHeaders();
-    
+
     // now uncollapse / collapse the right views
     collapsedNode.collapsed = false;
     expandedNode.collapsed = true;
-  }  
+  }
 
   var toggleHeaderView = GetHeaderPane();
   if (gCollapsedHeaderViewMode)
@@ -922,9 +942,9 @@ function UpdateMessageHeaders()
         }
       } catch (ex) {}
     }
-    
+
     if (gCollapsedHeaderViewMode && !gBuiltCollapsedView)
-    { 
+    {
       if (headerName in gCollapsedHeaderView)
         headerEntry = gCollapsedHeaderView[headerName];
     }
@@ -960,7 +980,7 @@ function UpdateMessageHeaders()
       {
         // hide references header if view all headers mode isn't selected, the pref show references is
         // deactivated and the currently displayed message isn't a newsgroup posting
-        headerEntry.valid = false;   
+        headerEntry.valid = false;
       }
       else
       {
@@ -997,7 +1017,7 @@ function ShowMessageHeaderPane()
 {
   var node;
   if (gCollapsedHeaderViewMode)
-  {          
+  {
     node = document.getElementById("collapsedHeaderView");
     if (node)
       node.collapsed = false;
@@ -1010,11 +1030,11 @@ function ShowMessageHeaderPane()
   }
 
   /* workaround for 39655 */
-  if (gFolderJustSwitched) 
+  if (gFolderJustSwitched)
   {
     let el = GetHeaderPane();
     el.setAttribute("style", el.getAttribute("style"));
-    gFolderJustSwitched = false;    
+    gFolderJustSwitched = false;
   }
 
   document.commandDispatcher.updateCommands("message-header-pane");
@@ -1098,7 +1118,7 @@ function OutputEmailAddresses(headerEntry, emailAddresses)
 
       index++;
     }
-    
+
     if (headerEntry.useToggle)
       headerEntry.enclosingBox.buildViews();
   } // if msgheader parser
@@ -1347,12 +1367,41 @@ function createNewAttachmentInfo(contentType, url, displayName, uri,
                                  isExternalAttachment, size)
 {
   this.contentType = contentType;
-  this.url = url;
   this.displayName = displayName;
   this.uri = uri;
   this.isExternalAttachment = isExternalAttachment;
   this.attachment = this;
   this.size = size;
+  let match;
+
+  // Remote urls, unlike non external mail part urls, may also contain query
+  // strings starting with ?; PART_RE does not handle this.
+  if (url.startsWith("http") || url.startsWith("file")) {
+    match = url.match(/[?&]part=[^&]+$/);
+    match = match && match[0];
+    this.partID = match && match.split("part=")[1];
+    url = url.replace(match, "");
+  }
+  else {
+    match = GlodaUtils.PART_RE.exec(url);
+    this.partID = match && match[1];
+  }
+
+  // Make sure to communicate it if it's an external http attachment and not a
+  // local attachment. For feeds attachments (enclosures) are always remote,
+  // so there is nothing to communicate.
+  if (isExternalAttachment && url.startsWith("http") &&
+      !gFolderDisplay.selectedMessageIsFeed) {
+    if (this.displayName) {
+      this.displayName = url + " - " + this.displayName;
+    }
+    else {
+      this.displayName = url;
+    }
+  }
+
+  this.url = url;
+
 }
 
 createNewAttachmentInfo.prototype.saveAttachment = function saveAttachment()
@@ -1461,7 +1510,7 @@ function onShowAttachmentContextMenu()
 {
   // if no attachments are selected, disable the Open and Save...
   var attachmentList = document.getElementById('attachmentList');
-  var selectedAttachments = attachmentList.selectedItems;
+  var selectedAttachments = [...attachmentList.selectedItems];
   var openMenu = document.getElementById('context-openAttachment');
   var viewMenu = document.getElementById('context-viewAttachment');
   var saveMenu = document.getElementById('context-saveAttachment');
@@ -1541,12 +1590,12 @@ function attachmentListClick(event)
 }
 
 // on command handlers for the attachment list context menu...
-// commandPrefix matches one of our existing functions 
+// commandPrefix matches one of our existing functions
 // (openAttachment, saveAttachment, etc.)
 function handleAttachmentSelection(commandPrefix)
 {
   var attachmentList = document.getElementById('attachmentList');
-  var selectedAttachments = attachmentList.selectedItems;
+  var selectedAttachments = [...attachmentList.selectedItems];
   if (selectedAttachments.length > 1)
     HandleMultipleAttachments(commandPrefix, selectedAttachments);
   else
@@ -1581,7 +1630,7 @@ function displayAttachmentsForExpandedView()
         nameAndSize += " (" + messenger.formatFileSize(attachment.size) + ")";
       let item = attachmentList.appendItem(nameAndSize, "");
       item.setAttribute("crop", "center");
-      item.setAttribute("class", "listitem-iconic attachment-item"); 
+      item.setAttribute("class", "listitem-iconic attachment-item");
       item.setAttribute("tooltiptext", attachment.displayName);
       item.attachment = attachment;
       item.setAttribute("attachmentUrl", attachment.url);
@@ -1592,11 +1641,11 @@ function displayAttachmentsForExpandedView()
         item.setAttribute('disabled', 'true');
       else
         setApplicationIconForAttachment(attachment, item);
-    } // for each attachment   
+    } // for each attachment
 
     gBuildAttachmentsForCurrentMsg = true;
   }
-   
+
   var expandedAttachmentBox = document.getElementById('expandedAttachmentBox');
   expandedAttachmentBox.collapsed = numAttachments <= 0;
 }
@@ -1710,7 +1759,7 @@ function FillAttachmentItemPopup(event)
   openpopup.removeEventListener('popupshowing', FillAttachmentItemPopup, false);
 
   var menuitementry = document.getElementById("context-openAttachment").cloneNode(false);
-  menuitementry.setAttribute('oncommand', 'this.parentNode.attachment.openAttachment();'); 
+  menuitementry.setAttribute('oncommand', 'this.parentNode.attachment.openAttachment();');
   menuitementry = openpopup.appendChild(menuitementry);
 
   menuitementry = document.getElementById("context-viewAttachment").cloneNode(false);
@@ -1718,23 +1767,23 @@ function FillAttachmentItemPopup(event)
   menuitementry = openpopup.appendChild(menuitementry);
 
   menuitementry = document.getElementById("context-saveAttachment").cloneNode(false);
-  menuitementry.setAttribute('oncommand', 'this.parentNode.attachment.saveAttachment()'); 
+  menuitementry.setAttribute('oncommand', 'this.parentNode.attachment.saveAttachment()');
   menuitementry = openpopup.appendChild(menuitementry);
 
   openpopup.appendChild(document.createElement("menuseparator"));
 
   menuitementry = document.getElementById("context-detachAttachment").cloneNode(false);
-  menuitementry.setAttribute('oncommand', 'this.parentNode.attachment.detachAttachment()'); 
+  menuitementry.setAttribute('oncommand', 'this.parentNode.attachment.detachAttachment()');
   if (!canDetach)
     menuitementry.setAttribute('disabled', 'true');
   menuitementry = openpopup.appendChild(menuitementry);
 
   menuitementry = document.getElementById("context-deleteAttachment").cloneNode(false);
-  menuitementry.setAttribute('oncommand', 'this.attachment.deleteAttachment()'); 
+  menuitementry.setAttribute('oncommand', 'this.attachment.deleteAttachment()');
   if (!canDetach)
     menuitementry.setAttribute('disabled', 'true');
   menuitementry = openpopup.appendChild(menuitementry);
-} 
+}
 
 function HandleMultipleAttachments(commandPrefix, selectedAttachments)
 {
@@ -1840,7 +1889,7 @@ function CopyWebsiteAddress(websiteAddressNode)
     var contractid = "@mozilla.org/widget/clipboardhelper;1";
     var iid = Components.interfaces.nsIClipboardHelper;
     var clipboard = Components.classes[contractid].getService(iid);
-    clipboard.copyString(websiteAddress, document);
+    clipboard.copyString(websiteAddress);
   }
 }
 
@@ -1975,7 +2024,7 @@ nsDummyMsgHeader.prototype =
   recipients : null,
   from : null,
   subject : "",
-  get mime2DecodedSubject() { return this.subject; },  
+  get mime2DecodedSubject() { return this.subject; },
   ccList : null,
   messageId : null,
   listPost : null,
